from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.get_pages_response_200_data_pages_data_item import GetPagesResponse200DataPagesDataItem


T = TypeVar("T", bound="GetPagesResponse200DataPages")


@attr.s(auto_attribs=True)
class GetPagesResponse200DataPages:
    """
    Attributes:
        current_page (Union[Unset, int]): The current page number Example: 1.
        data (Union[Unset, List['GetPagesResponse200DataPagesDataItem']]):
        first_page_url (Union[Unset, str]): The first page url Example: https://app.customgpt.ai/api/v1/users?page=1.
        from_ (Union[Unset, int]): The first item number of the current page Example: 1.
        last_page (Union[Unset, int]): The last page number Example: 1.
        last_page_url (Union[Unset, str]): The last page url Example: https://app.customgpt.ai/api/v1/users?page=1.
        next_page_url (Union[Unset, str]): The next page url Example: https://app.customgpt.ai/api/v1/users?page=1.
        path (Union[Unset, str]): The current page url Example: https://app.customgpt.ai/api/v1/users?page=1.
        per_page (Union[Unset, int]): The number of items per page Example: 10.
        prev_page_url (Union[Unset, str]): The previous page url Example: https://app.customgpt.ai/api/v1/users?page=1.
        to (Union[Unset, int]): The last item number of the current page Example: 1.
        total (Union[Unset, int]): The total number of items Example: 1.
    """

    current_page: Union[Unset, int] = UNSET
    data: Union[Unset, List["GetPagesResponse200DataPagesDataItem"]] = UNSET
    first_page_url: Union[Unset, str] = UNSET
    from_: Union[Unset, int] = UNSET
    last_page: Union[Unset, int] = UNSET
    last_page_url: Union[Unset, str] = UNSET
    next_page_url: Union[Unset, str] = UNSET
    path: Union[Unset, str] = UNSET
    per_page: Union[Unset, int] = UNSET
    prev_page_url: Union[Unset, str] = UNSET
    to: Union[Unset, int] = UNSET
    total: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        current_page = self.current_page
        data: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.data, Unset):
            data = []
            for data_item_data in self.data:
                data_item = data_item_data.to_dict()

                data.append(data_item)

        first_page_url = self.first_page_url
        from_ = self.from_
        last_page = self.last_page
        last_page_url = self.last_page_url
        next_page_url = self.next_page_url
        path = self.path
        per_page = self.per_page
        prev_page_url = self.prev_page_url
        to = self.to
        total = self.total

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if current_page is not UNSET:
            field_dict["current_page"] = current_page
        if data is not UNSET:
            for index, field_value in enumerate(data):
                field_dict[f"data[{index}]"] = field_value
        if first_page_url is not UNSET:
            field_dict["first_page_url"] = first_page_url
        if from_ is not UNSET:
            field_dict["from"] = from_
        if last_page is not UNSET:
            field_dict["last_page"] = last_page
        if last_page_url is not UNSET:
            field_dict["last_page_url"] = last_page_url
        if next_page_url is not UNSET:
            field_dict["next_page_url"] = next_page_url
        if path is not UNSET:
            field_dict["path"] = path
        if per_page is not UNSET:
            field_dict["per_page"] = per_page
        if prev_page_url is not UNSET:
            field_dict["prev_page_url"] = prev_page_url
        if to is not UNSET:
            field_dict["to"] = to
        if total is not UNSET:
            field_dict["total"] = total

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.get_pages_response_200_data_pages_data_item import GetPagesResponse200DataPagesDataItem

        current_page = src_dict.get("current_page")

        data = []
        _data = src_dict.get("data")
        for data_item_data in _data or []:
            data_item = GetPagesResponse200DataPagesDataItem.from_dict(data_item_data)

            data.append(data_item)

        first_page_url = src_dict.get("first_page_url")

        from_ = src_dict.get("from")

        last_page = src_dict.get("last_page")

        last_page_url = src_dict.get("last_page_url")

        next_page_url = src_dict.get("next_page_url")

        path = src_dict.get("path")

        per_page = src_dict.get("per_page")

        prev_page_url = src_dict.get("prev_page_url")

        to = src_dict.get("to")

        total = src_dict.get("total")

        get_pages_response_200_data_pages = cls(
            current_page=current_page,
            data=data,
            first_page_url=first_page_url,
            from_=from_,
            last_page=last_page,
            last_page_url=last_page_url,
            next_page_url=next_page_url,
            path=path,
            per_page=per_page,
            prev_page_url=prev_page_url,
            to=to,
            total=total,
        )

        get_pages_response_200_data_pages.additional_properties = src_dict
        return get_pages_response_200_data_pages

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



""" Contains all the data models used in inputs/outputs """

from .analysis_reports_filters_item import AnalysisReportsFiltersItem
from .analysis_reports_interval import AnalysisReportsInterval
from .analysis_reports_response_200 import AnalysisReportsResponse200
from .analysis_reports_response_200_data import AnalysisReportsResponse200Data
from .analysis_reports_response_200_data_conversations_item import AnalysisReportsResponse200DataConversationsItem
from .analysis_reports_response_200_data_queries_item import AnalysisReportsResponse200DataQueriesItem
from .analysis_reports_response_200_data_queries_per_conversation_item import (
    AnalysisReportsResponse200DataQueriesPerConversationItem,
)
from .analysis_reports_response_200_status import AnalysisReportsResponse200Status
from .analysis_reports_response_400 import AnalysisReportsResponse400
from .analysis_reports_response_400_data import AnalysisReportsResponse400Data
from .analysis_reports_response_400_data_code import AnalysisReportsResponse400DataCode
from .analysis_reports_response_400_status import AnalysisReportsResponse400Status
from .analysis_reports_response_401 import AnalysisReportsResponse401
from .analysis_reports_response_401_data import AnalysisReportsResponse401Data
from .analysis_reports_response_401_data_code import AnalysisReportsResponse401DataCode
from .analysis_reports_response_401_status import AnalysisReportsResponse401Status
from .analysis_reports_response_404 import AnalysisReportsResponse404
from .analysis_reports_response_404_data import AnalysisReportsResponse404Data
from .analysis_reports_response_404_data_code import AnalysisReportsResponse404DataCode
from .analysis_reports_response_404_data_message import AnalysisReportsResponse404DataMessage
from .analysis_reports_response_404_status import AnalysisReportsResponse404Status
from .analysis_reports_response_500 import AnalysisReportsResponse500
from .analysis_reports_response_500_data import AnalysisReportsResponse500Data
from .analysis_reports_response_500_data_code import AnalysisReportsResponse500DataCode
from .analysis_reports_response_500_status import AnalysisReportsResponse500Status
from .conversation import Conversation
from .conversations_reports_filters_item import ConversationsReportsFiltersItem
from .conversations_reports_response_200 import ConversationsReportsResponse200
from .conversations_reports_response_200_data import ConversationsReportsResponse200Data
from .conversations_reports_response_200_status import ConversationsReportsResponse200Status
from .conversations_reports_response_400 import ConversationsReportsResponse400
from .conversations_reports_response_400_data import ConversationsReportsResponse400Data
from .conversations_reports_response_400_data_code import ConversationsReportsResponse400DataCode
from .conversations_reports_response_400_status import ConversationsReportsResponse400Status
from .conversations_reports_response_401 import ConversationsReportsResponse401
from .conversations_reports_response_401_data import ConversationsReportsResponse401Data
from .conversations_reports_response_401_data_code import ConversationsReportsResponse401DataCode
from .conversations_reports_response_401_status import ConversationsReportsResponse401Status
from .conversations_reports_response_404 import ConversationsReportsResponse404
from .conversations_reports_response_404_data import ConversationsReportsResponse404Data
from .conversations_reports_response_404_data_code import ConversationsReportsResponse404DataCode
from .conversations_reports_response_404_data_message import ConversationsReportsResponse404DataMessage
from .conversations_reports_response_404_status import ConversationsReportsResponse404Status
from .conversations_reports_response_500 import ConversationsReportsResponse500
from .conversations_reports_response_500_data import ConversationsReportsResponse500Data
from .conversations_reports_response_500_data_code import ConversationsReportsResponse500DataCode
from .conversations_reports_response_500_status import ConversationsReportsResponse500Status
from .create_conversation_json_body import CreateConversationJsonBody
from .create_conversation_response_201 import CreateConversationResponse201
from .create_conversation_response_201_data import CreateConversationResponse201Data
from .create_conversation_response_201_status import CreateConversationResponse201Status
from .create_conversation_response_400 import CreateConversationResponse400
from .create_conversation_response_400_data import CreateConversationResponse400Data
from .create_conversation_response_400_data_code import CreateConversationResponse400DataCode
from .create_conversation_response_400_status import CreateConversationResponse400Status
from .create_conversation_response_401 import CreateConversationResponse401
from .create_conversation_response_401_data import CreateConversationResponse401Data
from .create_conversation_response_401_data_code import CreateConversationResponse401DataCode
from .create_conversation_response_401_status import CreateConversationResponse401Status
from .create_conversation_response_404 import CreateConversationResponse404
from .create_conversation_response_404_data import CreateConversationResponse404Data
from .create_conversation_response_404_data_code import CreateConversationResponse404DataCode
from .create_conversation_response_404_data_message import CreateConversationResponse404DataMessage
from .create_conversation_response_404_status import CreateConversationResponse404Status
from .create_conversation_response_500 import CreateConversationResponse500
from .create_conversation_response_500_data import CreateConversationResponse500Data
from .create_conversation_response_500_data_code import CreateConversationResponse500DataCode
from .create_conversation_response_500_status import CreateConversationResponse500Status
from .create_plugin_json_body import CreatePluginJsonBody
from .create_plugin_response_201 import CreatePluginResponse201
from .create_plugin_response_201_data import CreatePluginResponse201Data
from .create_plugin_response_201_status import CreatePluginResponse201Status
from .create_plugin_response_400 import CreatePluginResponse400
from .create_plugin_response_400_data import CreatePluginResponse400Data
from .create_plugin_response_400_data_code import CreatePluginResponse400DataCode
from .create_plugin_response_400_status import CreatePluginResponse400Status
from .create_plugin_response_401 import CreatePluginResponse401
from .create_plugin_response_401_data import CreatePluginResponse401Data
from .create_plugin_response_401_data_code import CreatePluginResponse401DataCode
from .create_plugin_response_401_status import CreatePluginResponse401Status
from .create_plugin_response_404 import CreatePluginResponse404
from .create_plugin_response_404_data import CreatePluginResponse404Data
from .create_plugin_response_404_data_code import CreatePluginResponse404DataCode
from .create_plugin_response_404_data_message import CreatePluginResponse404DataMessage
from .create_plugin_response_404_status import CreatePluginResponse404Status
from .create_plugin_response_500 import CreatePluginResponse500
from .create_plugin_response_500_data import CreatePluginResponse500Data
from .create_plugin_response_500_data_code import CreatePluginResponse500DataCode
from .create_plugin_response_500_status import CreatePluginResponse500Status
from .create_project_multipart_data import CreateProjectMultipartData
from .create_project_response_201 import CreateProjectResponse201
from .create_project_response_201_data import CreateProjectResponse201Data
from .create_project_response_201_data_type import CreateProjectResponse201DataType
from .create_project_response_201_status import CreateProjectResponse201Status
from .create_project_response_400 import CreateProjectResponse400
from .create_project_response_400_data import CreateProjectResponse400Data
from .create_project_response_400_data_code import CreateProjectResponse400DataCode
from .create_project_response_400_data_message import CreateProjectResponse400DataMessage
from .create_project_response_400_status import CreateProjectResponse400Status
from .create_project_response_401 import CreateProjectResponse401
from .create_project_response_401_data import CreateProjectResponse401Data
from .create_project_response_401_data_code import CreateProjectResponse401DataCode
from .create_project_response_401_status import CreateProjectResponse401Status
from .create_project_response_500 import CreateProjectResponse500
from .create_project_response_500_data import CreateProjectResponse500Data
from .create_project_response_500_data_code import CreateProjectResponse500DataCode
from .create_project_response_500_status import CreateProjectResponse500Status
from .create_source_multipart_data import CreateSourceMultipartData
from .create_source_response_201 import CreateSourceResponse201
from .create_source_response_201_data import CreateSourceResponse201Data
from .create_source_response_201_data_pages_item import CreateSourceResponse201DataPagesItem
from .create_source_response_201_data_pages_item_crawl_status import CreateSourceResponse201DataPagesItemCrawlStatus
from .create_source_response_201_data_pages_item_index_status import CreateSourceResponse201DataPagesItemIndexStatus
from .create_source_response_201_data_settings import CreateSourceResponse201DataSettings
from .create_source_response_201_data_settings_data_refresh_frequency import (
    CreateSourceResponse201DataSettingsDataRefreshFrequency,
)
from .create_source_response_201_data_settings_refresh_existing_pages import (
    CreateSourceResponse201DataSettingsRefreshExistingPages,
)
from .create_source_response_201_data_type import CreateSourceResponse201DataType
from .create_source_response_201_status import CreateSourceResponse201Status
from .create_source_response_400 import CreateSourceResponse400
from .create_source_response_400_data import CreateSourceResponse400Data
from .create_source_response_400_data_code import CreateSourceResponse400DataCode
from .create_source_response_400_status import CreateSourceResponse400Status
from .create_source_response_401 import CreateSourceResponse401
from .create_source_response_401_data import CreateSourceResponse401Data
from .create_source_response_401_data_code import CreateSourceResponse401DataCode
from .create_source_response_401_status import CreateSourceResponse401Status
from .create_source_response_404 import CreateSourceResponse404
from .create_source_response_404_data import CreateSourceResponse404Data
from .create_source_response_404_data_code import CreateSourceResponse404DataCode
from .create_source_response_404_data_message import CreateSourceResponse404DataMessage
from .create_source_response_404_status import CreateSourceResponse404Status
from .create_source_response_500 import CreateSourceResponse500
from .create_source_response_500_data import CreateSourceResponse500Data
from .create_source_response_500_data_code import CreateSourceResponse500DataCode
from .create_source_response_500_status import CreateSourceResponse500Status
from .delete_conversation_response_200 import DeleteConversationResponse200
from .delete_conversation_response_200_data import DeleteConversationResponse200Data
from .delete_conversation_response_200_status import DeleteConversationResponse200Status
from .delete_conversation_response_400 import DeleteConversationResponse400
from .delete_conversation_response_400_data import DeleteConversationResponse400Data
from .delete_conversation_response_400_data_code import DeleteConversationResponse400DataCode
from .delete_conversation_response_400_status import DeleteConversationResponse400Status
from .delete_conversation_response_401 import DeleteConversationResponse401
from .delete_conversation_response_401_data import DeleteConversationResponse401Data
from .delete_conversation_response_401_data_code import DeleteConversationResponse401DataCode
from .delete_conversation_response_401_status import DeleteConversationResponse401Status
from .delete_conversation_response_404 import DeleteConversationResponse404
from .delete_conversation_response_404_data import DeleteConversationResponse404Data
from .delete_conversation_response_404_data_code import DeleteConversationResponse404DataCode
from .delete_conversation_response_404_data_message import DeleteConversationResponse404DataMessage
from .delete_conversation_response_404_status import DeleteConversationResponse404Status
from .delete_conversation_response_500 import DeleteConversationResponse500
from .delete_conversation_response_500_data import DeleteConversationResponse500Data
from .delete_conversation_response_500_data_code import DeleteConversationResponse500DataCode
from .delete_conversation_response_500_status import DeleteConversationResponse500Status
from .delete_page_response_200 import DeletePageResponse200
from .delete_page_response_200_data import DeletePageResponse200Data
from .delete_page_response_200_status import DeletePageResponse200Status
from .delete_page_response_400 import DeletePageResponse400
from .delete_page_response_400_data import DeletePageResponse400Data
from .delete_page_response_400_data_code import DeletePageResponse400DataCode
from .delete_page_response_400_status import DeletePageResponse400Status
from .delete_page_response_401 import DeletePageResponse401
from .delete_page_response_401_data import DeletePageResponse401Data
from .delete_page_response_401_data_code import DeletePageResponse401DataCode
from .delete_page_response_401_status import DeletePageResponse401Status
from .delete_page_response_404 import DeletePageResponse404
from .delete_page_response_404_data import DeletePageResponse404Data
from .delete_page_response_404_data_code import DeletePageResponse404DataCode
from .delete_page_response_404_data_message import DeletePageResponse404DataMessage
from .delete_page_response_404_status import DeletePageResponse404Status
from .delete_page_response_500 import DeletePageResponse500
from .delete_page_response_500_data import DeletePageResponse500Data
from .delete_page_response_500_data_code import DeletePageResponse500DataCode
from .delete_page_response_500_status import DeletePageResponse500Status
from .delete_project_response_200 import DeleteProjectResponse200
from .delete_project_response_200_data import DeleteProjectResponse200Data
from .delete_project_response_200_status import DeleteProjectResponse200Status
from .delete_project_response_400 import DeleteProjectResponse400
from .delete_project_response_400_data import DeleteProjectResponse400Data
from .delete_project_response_400_data_code import DeleteProjectResponse400DataCode
from .delete_project_response_400_status import DeleteProjectResponse400Status
from .delete_project_response_401 import DeleteProjectResponse401
from .delete_project_response_401_data import DeleteProjectResponse401Data
from .delete_project_response_401_data_code import DeleteProjectResponse401DataCode
from .delete_project_response_401_status import DeleteProjectResponse401Status
from .delete_project_response_404 import DeleteProjectResponse404
from .delete_project_response_404_data import DeleteProjectResponse404Data
from .delete_project_response_404_data_code import DeleteProjectResponse404DataCode
from .delete_project_response_404_data_message import DeleteProjectResponse404DataMessage
from .delete_project_response_404_status import DeleteProjectResponse404Status
from .delete_project_response_500 import DeleteProjectResponse500
from .delete_project_response_500_data import DeleteProjectResponse500Data
from .delete_project_response_500_data_code import DeleteProjectResponse500DataCode
from .delete_project_response_500_status import DeleteProjectResponse500Status
from .delete_source_response_200 import DeleteSourceResponse200
from .delete_source_response_200_data import DeleteSourceResponse200Data
from .delete_source_response_200_status import DeleteSourceResponse200Status
from .delete_source_response_400 import DeleteSourceResponse400
from .delete_source_response_400_data import DeleteSourceResponse400Data
from .delete_source_response_400_data_code import DeleteSourceResponse400DataCode
from .delete_source_response_400_status import DeleteSourceResponse400Status
from .delete_source_response_401 import DeleteSourceResponse401
from .delete_source_response_401_data import DeleteSourceResponse401Data
from .delete_source_response_401_data_code import DeleteSourceResponse401DataCode
from .delete_source_response_401_status import DeleteSourceResponse401Status
from .delete_source_response_404 import DeleteSourceResponse404
from .delete_source_response_404_data import DeleteSourceResponse404Data
from .delete_source_response_404_data_code import DeleteSourceResponse404DataCode
from .delete_source_response_404_data_message import DeleteSourceResponse404DataMessage
from .delete_source_response_404_status import DeleteSourceResponse404Status
from .delete_source_response_500 import DeleteSourceResponse500
from .delete_source_response_500_data import DeleteSourceResponse500Data
from .delete_source_response_500_data_code import DeleteSourceResponse500DataCode
from .delete_source_response_500_status import DeleteSourceResponse500Status
from .get_api_v1_limits_usage_response_200 import GetApiV1LimitsUsageResponse200
from .get_api_v1_limits_usage_response_200_data import GetApiV1LimitsUsageResponse200Data
from .get_api_v1_limits_usage_response_200_status import GetApiV1LimitsUsageResponse200Status
from .get_api_v1_limits_usage_response_401 import GetApiV1LimitsUsageResponse401
from .get_api_v1_limits_usage_response_401_data import GetApiV1LimitsUsageResponse401Data
from .get_api_v1_limits_usage_response_401_data_code import GetApiV1LimitsUsageResponse401DataCode
from .get_api_v1_limits_usage_response_401_status import GetApiV1LimitsUsageResponse401Status
from .get_api_v1_limits_usage_response_500 import GetApiV1LimitsUsageResponse500
from .get_api_v1_limits_usage_response_500_data import GetApiV1LimitsUsageResponse500Data
from .get_api_v1_limits_usage_response_500_data_code import GetApiV1LimitsUsageResponse500DataCode
from .get_api_v1_limits_usage_response_500_status import GetApiV1LimitsUsageResponse500Status
from .get_citation_response_200 import GetCitationResponse200
from .get_citation_response_200_data import GetCitationResponse200Data
from .get_citation_response_200_status import GetCitationResponse200Status
from .get_citation_response_400 import GetCitationResponse400
from .get_citation_response_400_data import GetCitationResponse400Data
from .get_citation_response_400_data_code import GetCitationResponse400DataCode
from .get_citation_response_400_status import GetCitationResponse400Status
from .get_citation_response_401 import GetCitationResponse401
from .get_citation_response_401_data import GetCitationResponse401Data
from .get_citation_response_401_data_code import GetCitationResponse401DataCode
from .get_citation_response_401_status import GetCitationResponse401Status
from .get_citation_response_404 import GetCitationResponse404
from .get_citation_response_404_data import GetCitationResponse404Data
from .get_citation_response_404_data_code import GetCitationResponse404DataCode
from .get_citation_response_404_data_message import GetCitationResponse404DataMessage
from .get_citation_response_404_status import GetCitationResponse404Status
from .get_conversations_order import GetConversationsOrder
from .get_conversations_order_by import GetConversationsOrderBy
from .get_conversations_response_200 import GetConversationsResponse200
from .get_conversations_response_200_data import GetConversationsResponse200Data
from .get_conversations_response_200_data_data_item import GetConversationsResponse200DataDataItem
from .get_conversations_response_200_status import GetConversationsResponse200Status
from .get_conversations_response_400 import GetConversationsResponse400
from .get_conversations_response_400_data import GetConversationsResponse400Data
from .get_conversations_response_400_data_code import GetConversationsResponse400DataCode
from .get_conversations_response_400_status import GetConversationsResponse400Status
from .get_conversations_response_401 import GetConversationsResponse401
from .get_conversations_response_401_data import GetConversationsResponse401Data
from .get_conversations_response_401_data_code import GetConversationsResponse401DataCode
from .get_conversations_response_401_status import GetConversationsResponse401Status
from .get_conversations_response_404 import GetConversationsResponse404
from .get_conversations_response_404_data import GetConversationsResponse404Data
from .get_conversations_response_404_data_code import GetConversationsResponse404DataCode
from .get_conversations_response_404_data_message import GetConversationsResponse404DataMessage
from .get_conversations_response_404_status import GetConversationsResponse404Status
from .get_conversations_response_500 import GetConversationsResponse500
from .get_conversations_response_500_data import GetConversationsResponse500Data
from .get_conversations_response_500_data_code import GetConversationsResponse500DataCode
from .get_conversations_response_500_status import GetConversationsResponse500Status
from .get_conversations_user_filter import GetConversationsUserFilter
from .get_metadata_response_200 import GetMetadataResponse200
from .get_metadata_response_200_data import GetMetadataResponse200Data
from .get_metadata_response_200_status import GetMetadataResponse200Status
from .get_metadata_response_400 import GetMetadataResponse400
from .get_metadata_response_400_data import GetMetadataResponse400Data
from .get_metadata_response_400_data_code import GetMetadataResponse400DataCode
from .get_metadata_response_400_status import GetMetadataResponse400Status
from .get_metadata_response_401 import GetMetadataResponse401
from .get_metadata_response_401_data import GetMetadataResponse401Data
from .get_metadata_response_401_data_code import GetMetadataResponse401DataCode
from .get_metadata_response_401_status import GetMetadataResponse401Status
from .get_metadata_response_404 import GetMetadataResponse404
from .get_metadata_response_404_data import GetMetadataResponse404Data
from .get_metadata_response_404_data_code import GetMetadataResponse404DataCode
from .get_metadata_response_404_data_message import GetMetadataResponse404DataMessage
from .get_metadata_response_404_status import GetMetadataResponse404Status
from .get_pages_order import GetPagesOrder
from .get_pages_response_200 import GetPagesResponse200
from .get_pages_response_200_data import GetPagesResponse200Data
from .get_pages_response_200_data_pages import GetPagesResponse200DataPages
from .get_pages_response_200_data_pages_data_item import GetPagesResponse200DataPagesDataItem
from .get_pages_response_200_data_pages_data_item_crawl_status import GetPagesResponse200DataPagesDataItemCrawlStatus
from .get_pages_response_200_data_pages_data_item_index_status import GetPagesResponse200DataPagesDataItemIndexStatus
from .get_pages_response_200_data_project import GetPagesResponse200DataProject
from .get_pages_response_200_data_project_type import GetPagesResponse200DataProjectType
from .get_pages_response_200_status import GetPagesResponse200Status
from .get_pages_response_400 import GetPagesResponse400
from .get_pages_response_400_data import GetPagesResponse400Data
from .get_pages_response_400_data_code import GetPagesResponse400DataCode
from .get_pages_response_400_status import GetPagesResponse400Status
from .get_pages_response_401 import GetPagesResponse401
from .get_pages_response_401_data import GetPagesResponse401Data
from .get_pages_response_401_data_code import GetPagesResponse401DataCode
from .get_pages_response_401_status import GetPagesResponse401Status
from .get_pages_response_404 import GetPagesResponse404
from .get_pages_response_404_data import GetPagesResponse404Data
from .get_pages_response_404_data_code import GetPagesResponse404DataCode
from .get_pages_response_404_data_message import GetPagesResponse404DataMessage
from .get_pages_response_404_status import GetPagesResponse404Status
from .get_pages_response_500 import GetPagesResponse500
from .get_pages_response_500_data import GetPagesResponse500Data
from .get_pages_response_500_data_code import GetPagesResponse500DataCode
from .get_pages_response_500_status import GetPagesResponse500Status
from .get_plugin_response_200 import GetPluginResponse200
from .get_plugin_response_200_data import GetPluginResponse200Data
from .get_plugin_response_200_status import GetPluginResponse200Status
from .get_plugin_response_400 import GetPluginResponse400
from .get_plugin_response_400_data import GetPluginResponse400Data
from .get_plugin_response_400_data_code import GetPluginResponse400DataCode
from .get_plugin_response_400_status import GetPluginResponse400Status
from .get_plugin_response_401 import GetPluginResponse401
from .get_plugin_response_401_data import GetPluginResponse401Data
from .get_plugin_response_401_data_code import GetPluginResponse401DataCode
from .get_plugin_response_401_status import GetPluginResponse401Status
from .get_plugin_response_404 import GetPluginResponse404
from .get_plugin_response_404_data import GetPluginResponse404Data
from .get_plugin_response_404_data_code import GetPluginResponse404DataCode
from .get_plugin_response_404_data_message import GetPluginResponse404DataMessage
from .get_plugin_response_404_status import GetPluginResponse404Status
from .get_plugin_response_500 import GetPluginResponse500
from .get_plugin_response_500_data import GetPluginResponse500Data
from .get_plugin_response_500_data_code import GetPluginResponse500DataCode
from .get_plugin_response_500_status import GetPluginResponse500Status
from .get_project_response_200 import GetProjectResponse200
from .get_project_response_200_data import GetProjectResponse200Data
from .get_project_response_200_data_type import GetProjectResponse200DataType
from .get_project_response_200_status import GetProjectResponse200Status
from .get_project_response_400 import GetProjectResponse400
from .get_project_response_400_data import GetProjectResponse400Data
from .get_project_response_400_data_code import GetProjectResponse400DataCode
from .get_project_response_400_status import GetProjectResponse400Status
from .get_project_response_401 import GetProjectResponse401
from .get_project_response_401_data import GetProjectResponse401Data
from .get_project_response_401_data_code import GetProjectResponse401DataCode
from .get_project_response_401_status import GetProjectResponse401Status
from .get_project_response_404 import GetProjectResponse404
from .get_project_response_404_data import GetProjectResponse404Data
from .get_project_response_404_data_code import GetProjectResponse404DataCode
from .get_project_response_404_data_message import GetProjectResponse404DataMessage
from .get_project_response_404_status import GetProjectResponse404Status
from .get_project_response_500 import GetProjectResponse500
from .get_project_response_500_data import GetProjectResponse500Data
from .get_project_response_500_data_code import GetProjectResponse500DataCode
from .get_project_response_500_status import GetProjectResponse500Status
from .get_project_settings_response_200 import GetProjectSettingsResponse200
from .get_project_settings_response_200_data import GetProjectSettingsResponse200Data
from .get_project_settings_response_200_data_chatbot_model import GetProjectSettingsResponse200DataChatbotModel
from .get_project_settings_response_200_data_citations_view_type import (
    GetProjectSettingsResponse200DataCitationsViewType,
)
from .get_project_settings_response_200_data_enable_citations import GetProjectSettingsResponse200DataEnableCitations
from .get_project_settings_response_200_data_response_source import GetProjectSettingsResponse200DataResponseSource
from .get_project_settings_response_200_status import GetProjectSettingsResponse200Status
from .get_project_settings_response_400 import GetProjectSettingsResponse400
from .get_project_settings_response_400_data import GetProjectSettingsResponse400Data
from .get_project_settings_response_400_data_code import GetProjectSettingsResponse400DataCode
from .get_project_settings_response_400_status import GetProjectSettingsResponse400Status
from .get_project_settings_response_401 import GetProjectSettingsResponse401
from .get_project_settings_response_401_data import GetProjectSettingsResponse401Data
from .get_project_settings_response_401_data_code import GetProjectSettingsResponse401DataCode
from .get_project_settings_response_401_status import GetProjectSettingsResponse401Status
from .get_project_settings_response_404 import GetProjectSettingsResponse404
from .get_project_settings_response_404_data import GetProjectSettingsResponse404Data
from .get_project_settings_response_404_data_code import GetProjectSettingsResponse404DataCode
from .get_project_settings_response_404_data_message import GetProjectSettingsResponse404DataMessage
from .get_project_settings_response_404_status import GetProjectSettingsResponse404Status
from .get_project_settings_response_500 import GetProjectSettingsResponse500
from .get_project_settings_response_500_data import GetProjectSettingsResponse500Data
from .get_project_settings_response_500_data_code import GetProjectSettingsResponse500DataCode
from .get_project_settings_response_500_status import GetProjectSettingsResponse500Status
from .get_user_response_200 import GetUserResponse200
from .get_user_response_200_data import GetUserResponse200Data
from .get_user_response_200_status import GetUserResponse200Status
from .get_user_response_401 import GetUserResponse401
from .get_user_response_401_data import GetUserResponse401Data
from .get_user_response_401_data_code import GetUserResponse401DataCode
from .get_user_response_401_status import GetUserResponse401Status
from .get_user_response_500 import GetUserResponse500
from .get_user_response_500_data import GetUserResponse500Data
from .get_user_response_500_data_code import GetUserResponse500DataCode
from .get_user_response_500_status import GetUserResponse500Status
from .list_projects_order import ListProjectsOrder
from .list_projects_order_by import ListProjectsOrderBy
from .list_projects_response_200 import ListProjectsResponse200
from .list_projects_response_200_data import ListProjectsResponse200Data
from .list_projects_response_200_data_data_item import ListProjectsResponse200DataDataItem
from .list_projects_response_200_data_data_item_type import ListProjectsResponse200DataDataItemType
from .list_projects_response_200_status import ListProjectsResponse200Status
from .list_projects_response_401 import ListProjectsResponse401
from .list_projects_response_401_data import ListProjectsResponse401Data
from .list_projects_response_401_data_code import ListProjectsResponse401DataCode
from .list_projects_response_401_status import ListProjectsResponse401Status
from .list_projects_response_500 import ListProjectsResponse500
from .list_projects_response_500_data import ListProjectsResponse500Data
from .list_projects_response_500_data_code import ListProjectsResponse500DataCode
from .list_projects_response_500_status import ListProjectsResponse500Status
from .list_sources_response_200 import ListSourcesResponse200
from .list_sources_response_200_data import ListSourcesResponse200Data
from .list_sources_response_200_data_sitemaps_item import ListSourcesResponse200DataSitemapsItem
from .list_sources_response_200_data_sitemaps_item_pages_item import ListSourcesResponse200DataSitemapsItemPagesItem
from .list_sources_response_200_data_sitemaps_item_pages_item_crawl_status import (
    ListSourcesResponse200DataSitemapsItemPagesItemCrawlStatus,
)
from .list_sources_response_200_data_sitemaps_item_pages_item_index_status import (
    ListSourcesResponse200DataSitemapsItemPagesItemIndexStatus,
)
from .list_sources_response_200_data_sitemaps_item_settings import ListSourcesResponse200DataSitemapsItemSettings
from .list_sources_response_200_data_sitemaps_item_settings_data_refresh_frequency import (
    ListSourcesResponse200DataSitemapsItemSettingsDataRefreshFrequency,
)
from .list_sources_response_200_data_sitemaps_item_settings_refresh_existing_pages import (
    ListSourcesResponse200DataSitemapsItemSettingsRefreshExistingPages,
)
from .list_sources_response_200_data_sitemaps_item_type import ListSourcesResponse200DataSitemapsItemType
from .list_sources_response_200_data_uploads import ListSourcesResponse200DataUploads
from .list_sources_response_200_data_uploads_pages_item import ListSourcesResponse200DataUploadsPagesItem
from .list_sources_response_200_data_uploads_pages_item_crawl_status import (
    ListSourcesResponse200DataUploadsPagesItemCrawlStatus,
)
from .list_sources_response_200_data_uploads_pages_item_index_status import (
    ListSourcesResponse200DataUploadsPagesItemIndexStatus,
)
from .list_sources_response_200_data_uploads_settings import ListSourcesResponse200DataUploadsSettings
from .list_sources_response_200_data_uploads_settings_data_refresh_frequency import (
    ListSourcesResponse200DataUploadsSettingsDataRefreshFrequency,
)
from .list_sources_response_200_data_uploads_settings_refresh_existing_pages import (
    ListSourcesResponse200DataUploadsSettingsRefreshExistingPages,
)
from .list_sources_response_200_data_uploads_type import ListSourcesResponse200DataUploadsType
from .list_sources_response_200_status import ListSourcesResponse200Status
from .list_sources_response_401 import ListSourcesResponse401
from .list_sources_response_401_data import ListSourcesResponse401Data
from .list_sources_response_401_data_code import ListSourcesResponse401DataCode
from .list_sources_response_401_status import ListSourcesResponse401Status
from .list_sources_response_500 import ListSourcesResponse500
from .list_sources_response_500_data import ListSourcesResponse500Data
from .list_sources_response_500_data_code import ListSourcesResponse500DataCode
from .list_sources_response_500_status import ListSourcesResponse500Status
from .messages_conversation_order import MessagesConversationOrder
from .messages_conversation_response_200 import MessagesConversationResponse200
from .messages_conversation_response_200_data import MessagesConversationResponse200Data
from .messages_conversation_response_200_data_conversation import MessagesConversationResponse200DataConversation
from .messages_conversation_response_200_data_messages import MessagesConversationResponse200DataMessages
from .messages_conversation_response_200_data_messages_data_item import (
    MessagesConversationResponse200DataMessagesDataItem,
)
from .messages_conversation_response_200_data_messages_data_item_metadata import (
    MessagesConversationResponse200DataMessagesDataItemMetadata,
)
from .messages_conversation_response_200_status import MessagesConversationResponse200Status
from .messages_conversation_response_400 import MessagesConversationResponse400
from .messages_conversation_response_400_data import MessagesConversationResponse400Data
from .messages_conversation_response_400_data_code import MessagesConversationResponse400DataCode
from .messages_conversation_response_400_status import MessagesConversationResponse400Status
from .messages_conversation_response_401 import MessagesConversationResponse401
from .messages_conversation_response_401_data import MessagesConversationResponse401Data
from .messages_conversation_response_401_data_code import MessagesConversationResponse401DataCode
from .messages_conversation_response_401_status import MessagesConversationResponse401Status
from .messages_conversation_response_404 import MessagesConversationResponse404
from .messages_conversation_response_404_data import MessagesConversationResponse404Data
from .messages_conversation_response_404_data_code import MessagesConversationResponse404DataCode
from .messages_conversation_response_404_data_message import MessagesConversationResponse404DataMessage
from .messages_conversation_response_404_status import MessagesConversationResponse404Status
from .messages_conversation_response_500 import MessagesConversationResponse500
from .messages_conversation_response_500_data import MessagesConversationResponse500Data
from .messages_conversation_response_500_data_code import MessagesConversationResponse500DataCode
from .messages_conversation_response_500_status import MessagesConversationResponse500Status
from .page import Page
from .page_crawl_status import PageCrawlStatus
from .page_index_status import PageIndexStatus
from .page_metadata import PageMetadata
from .preview_citation_response_400 import PreviewCitationResponse400
from .preview_citation_response_400_data import PreviewCitationResponse400Data
from .preview_citation_response_400_data_code import PreviewCitationResponse400DataCode
from .preview_citation_response_400_status import PreviewCitationResponse400Status
from .preview_citation_response_401 import PreviewCitationResponse401
from .preview_citation_response_401_data import PreviewCitationResponse401Data
from .preview_citation_response_401_data_code import PreviewCitationResponse401DataCode
from .preview_citation_response_401_status import PreviewCitationResponse401Status
from .preview_citation_response_404 import PreviewCitationResponse404
from .preview_citation_response_404_data import PreviewCitationResponse404Data
from .preview_citation_response_404_data_code import PreviewCitationResponse404DataCode
from .preview_citation_response_404_data_message import PreviewCitationResponse404DataMessage
from .preview_citation_response_404_status import PreviewCitationResponse404Status
from .preview_citation_response_500 import PreviewCitationResponse500
from .preview_citation_response_500_data import PreviewCitationResponse500Data
from .preview_citation_response_500_data_code import PreviewCitationResponse500DataCode
from .preview_citation_response_500_status import PreviewCitationResponse500Status
from .project import Project
from .project_analytics_analysis import ProjectAnalyticsAnalysis
from .project_analytics_analysis_conversations_item import ProjectAnalyticsAnalysisConversationsItem
from .project_analytics_analysis_queries_item import ProjectAnalyticsAnalysisQueriesItem
from .project_analytics_analysis_queries_per_conversation_item import ProjectAnalyticsAnalysisQueriesPerConversationItem
from .project_analytics_conversation import ProjectAnalyticsConversation
from .project_analytics_query import ProjectAnalyticsQuery
from .project_analytics_query_query_status_item import ProjectAnalyticsQueryQueryStatusItem
from .project_analytics_query_query_status_item_status import ProjectAnalyticsQueryQueryStatusItemStatus
from .project_analytics_traffic import ProjectAnalyticsTraffic
from .project_analytics_traffic_sources_item import ProjectAnalyticsTrafficSourcesItem
from .project_analytics_traffic_sources_item_request_source import ProjectAnalyticsTrafficSourcesItemRequestSource
from .project_plugin import ProjectPlugin
from .project_settings import ProjectSettings
from .project_settings_chatbot_model import ProjectSettingsChatbotModel
from .project_settings_citations_view_type import ProjectSettingsCitationsViewType
from .project_settings_enable_citations import ProjectSettingsEnableCitations
from .project_settings_response_source import ProjectSettingsResponseSource
from .project_source import ProjectSource
from .project_source_pages_item import ProjectSourcePagesItem
from .project_source_pages_item_crawl_status import ProjectSourcePagesItemCrawlStatus
from .project_source_pages_item_index_status import ProjectSourcePagesItemIndexStatus
from .project_source_settings import ProjectSourceSettings
from .project_source_settings_data_refresh_frequency import ProjectSourceSettingsDataRefreshFrequency
from .project_source_settings_refresh_existing_pages import ProjectSourceSettingsRefreshExistingPages
from .project_source_type import ProjectSourceType
from .project_type import ProjectType
from .prompt_history import PromptHistory
from .prompt_history_metadata import PromptHistoryMetadata
from .queries_reports_filters_item import QueriesReportsFiltersItem
from .queries_reports_response_200 import QueriesReportsResponse200
from .queries_reports_response_200_data import QueriesReportsResponse200Data
from .queries_reports_response_200_data_query_status_item import QueriesReportsResponse200DataQueryStatusItem
from .queries_reports_response_200_data_query_status_item_status import (
    QueriesReportsResponse200DataQueryStatusItemStatus,
)
from .queries_reports_response_200_status import QueriesReportsResponse200Status
from .queries_reports_response_400 import QueriesReportsResponse400
from .queries_reports_response_400_data import QueriesReportsResponse400Data
from .queries_reports_response_400_data_code import QueriesReportsResponse400DataCode
from .queries_reports_response_400_status import QueriesReportsResponse400Status
from .queries_reports_response_401 import QueriesReportsResponse401
from .queries_reports_response_401_data import QueriesReportsResponse401Data
from .queries_reports_response_401_data_code import QueriesReportsResponse401DataCode
from .queries_reports_response_401_status import QueriesReportsResponse401Status
from .queries_reports_response_404 import QueriesReportsResponse404
from .queries_reports_response_404_data import QueriesReportsResponse404Data
from .queries_reports_response_404_data_code import QueriesReportsResponse404DataCode
from .queries_reports_response_404_data_message import QueriesReportsResponse404DataMessage
from .queries_reports_response_404_status import QueriesReportsResponse404Status
from .queries_reports_response_500 import QueriesReportsResponse500
from .queries_reports_response_500_data import QueriesReportsResponse500Data
from .queries_reports_response_500_data_code import QueriesReportsResponse500DataCode
from .queries_reports_response_500_status import QueriesReportsResponse500Status
from .reindex_page_response_200 import ReindexPageResponse200
from .reindex_page_response_200_data import ReindexPageResponse200Data
from .reindex_page_response_200_status import ReindexPageResponse200Status
from .reindex_page_response_400 import ReindexPageResponse400
from .reindex_page_response_400_data import ReindexPageResponse400Data
from .reindex_page_response_400_data_code import ReindexPageResponse400DataCode
from .reindex_page_response_400_status import ReindexPageResponse400Status
from .reindex_page_response_401 import ReindexPageResponse401
from .reindex_page_response_401_data import ReindexPageResponse401Data
from .reindex_page_response_401_data_code import ReindexPageResponse401DataCode
from .reindex_page_response_401_status import ReindexPageResponse401Status
from .reindex_page_response_403 import ReindexPageResponse403
from .reindex_page_response_403_data import ReindexPageResponse403Data
from .reindex_page_response_403_data_code import ReindexPageResponse403DataCode
from .reindex_page_response_403_data_message import ReindexPageResponse403DataMessage
from .reindex_page_response_403_status import ReindexPageResponse403Status
from .reindex_page_response_500 import ReindexPageResponse500
from .reindex_page_response_500_data import ReindexPageResponse500Data
from .reindex_page_response_500_data_code import ReindexPageResponse500DataCode
from .reindex_page_response_500_status import ReindexPageResponse500Status
from .replicate_project_response_201 import ReplicateProjectResponse201
from .replicate_project_response_201_data import ReplicateProjectResponse201Data
from .replicate_project_response_201_data_type import ReplicateProjectResponse201DataType
from .replicate_project_response_201_status import ReplicateProjectResponse201Status
from .replicate_project_response_400 import ReplicateProjectResponse400
from .replicate_project_response_400_data import ReplicateProjectResponse400Data
from .replicate_project_response_400_data_code import ReplicateProjectResponse400DataCode
from .replicate_project_response_400_data_message import ReplicateProjectResponse400DataMessage
from .replicate_project_response_400_status import ReplicateProjectResponse400Status
from .replicate_project_response_401 import ReplicateProjectResponse401
from .replicate_project_response_401_data import ReplicateProjectResponse401Data
from .replicate_project_response_401_data_code import ReplicateProjectResponse401DataCode
from .replicate_project_response_401_status import ReplicateProjectResponse401Status
from .replicate_project_response_500 import ReplicateProjectResponse500
from .replicate_project_response_500_data import ReplicateProjectResponse500Data
from .replicate_project_response_500_data_code import ReplicateProjectResponse500DataCode
from .replicate_project_response_500_status import ReplicateProjectResponse500Status
from .send_message_cache_control import SendMessageCacheControl
from .send_message_json_body import SendMessageJsonBody
from .send_message_json_body_chatbot_model import SendMessageJsonBodyChatbotModel
from .send_message_json_body_response_source import SendMessageJsonBodyResponseSource
from .send_message_response_200 import SendMessageResponse200
from .send_message_response_200_data import SendMessageResponse200Data
from .send_message_response_200_data_metadata import SendMessageResponse200DataMetadata
from .send_message_response_200_status import SendMessageResponse200Status
from .send_message_response_400 import SendMessageResponse400
from .send_message_response_400_data import SendMessageResponse400Data
from .send_message_response_400_data_code import SendMessageResponse400DataCode
from .send_message_response_400_status import SendMessageResponse400Status
from .send_message_response_401 import SendMessageResponse401
from .send_message_response_401_data import SendMessageResponse401Data
from .send_message_response_401_data_code import SendMessageResponse401DataCode
from .send_message_response_401_status import SendMessageResponse401Status
from .send_message_response_404 import SendMessageResponse404
from .send_message_response_404_data import SendMessageResponse404Data
from .send_message_response_404_data_code import SendMessageResponse404DataCode
from .send_message_response_404_data_message import SendMessageResponse404DataMessage
from .send_message_response_404_status import SendMessageResponse404Status
from .send_message_response_429 import SendMessageResponse429
from .send_message_response_429_data import SendMessageResponse429Data
from .send_message_response_429_data_code import SendMessageResponse429DataCode
from .send_message_response_429_status import SendMessageResponse429Status
from .send_message_response_500 import SendMessageResponse500
from .send_message_response_500_data import SendMessageResponse500Data
from .send_message_response_500_data_code import SendMessageResponse500DataCode
from .send_message_response_500_status import SendMessageResponse500Status
from .stats_project_response_200 import StatsProjectResponse200
from .stats_project_response_200_data import StatsProjectResponse200Data
from .stats_project_response_200_status import StatsProjectResponse200Status
from .stats_project_response_400 import StatsProjectResponse400
from .stats_project_response_400_data import StatsProjectResponse400Data
from .stats_project_response_400_data_code import StatsProjectResponse400DataCode
from .stats_project_response_400_status import StatsProjectResponse400Status
from .stats_project_response_401 import StatsProjectResponse401
from .stats_project_response_401_data import StatsProjectResponse401Data
from .stats_project_response_401_data_code import StatsProjectResponse401DataCode
from .stats_project_response_401_status import StatsProjectResponse401Status
from .stats_project_response_404 import StatsProjectResponse404
from .stats_project_response_404_data import StatsProjectResponse404Data
from .stats_project_response_404_data_code import StatsProjectResponse404DataCode
from .stats_project_response_404_data_message import StatsProjectResponse404DataMessage
from .stats_project_response_404_status import StatsProjectResponse404Status
from .stats_project_response_500 import StatsProjectResponse500
from .stats_project_response_500_data import StatsProjectResponse500Data
from .stats_project_response_500_data_code import StatsProjectResponse500DataCode
from .stats_project_response_500_status import StatsProjectResponse500Status
from .synchronize_source_response_201 import SynchronizeSourceResponse201
from .synchronize_source_response_201_data import SynchronizeSourceResponse201Data
from .synchronize_source_response_201_data_pages_item import SynchronizeSourceResponse201DataPagesItem
from .synchronize_source_response_201_data_pages_item_crawl_status import (
    SynchronizeSourceResponse201DataPagesItemCrawlStatus,
)
from .synchronize_source_response_201_data_pages_item_index_status import (
    SynchronizeSourceResponse201DataPagesItemIndexStatus,
)
from .synchronize_source_response_201_data_settings import SynchronizeSourceResponse201DataSettings
from .synchronize_source_response_201_data_settings_data_refresh_frequency import (
    SynchronizeSourceResponse201DataSettingsDataRefreshFrequency,
)
from .synchronize_source_response_201_data_settings_refresh_existing_pages import (
    SynchronizeSourceResponse201DataSettingsRefreshExistingPages,
)
from .synchronize_source_response_201_data_type import SynchronizeSourceResponse201DataType
from .synchronize_source_response_201_status import SynchronizeSourceResponse201Status
from .synchronize_source_response_400 import SynchronizeSourceResponse400
from .synchronize_source_response_400_data import SynchronizeSourceResponse400Data
from .synchronize_source_response_400_data_code import SynchronizeSourceResponse400DataCode
from .synchronize_source_response_400_status import SynchronizeSourceResponse400Status
from .synchronize_source_response_401 import SynchronizeSourceResponse401
from .synchronize_source_response_401_data import SynchronizeSourceResponse401Data
from .synchronize_source_response_401_data_code import SynchronizeSourceResponse401DataCode
from .synchronize_source_response_401_status import SynchronizeSourceResponse401Status
from .synchronize_source_response_403 import SynchronizeSourceResponse403
from .synchronize_source_response_403_data import SynchronizeSourceResponse403Data
from .synchronize_source_response_403_data_code import SynchronizeSourceResponse403DataCode
from .synchronize_source_response_403_data_message import SynchronizeSourceResponse403DataMessage
from .synchronize_source_response_403_status import SynchronizeSourceResponse403Status
from .synchronize_source_response_404 import SynchronizeSourceResponse404
from .synchronize_source_response_404_data import SynchronizeSourceResponse404Data
from .synchronize_source_response_404_data_code import SynchronizeSourceResponse404DataCode
from .synchronize_source_response_404_data_message import SynchronizeSourceResponse404DataMessage
from .synchronize_source_response_404_status import SynchronizeSourceResponse404Status
from .synchronize_source_response_500 import SynchronizeSourceResponse500
from .synchronize_source_response_500_data import SynchronizeSourceResponse500Data
from .synchronize_source_response_500_data_code import SynchronizeSourceResponse500DataCode
from .synchronize_source_response_500_status import SynchronizeSourceResponse500Status
from .time import Time
from .traffic_reports_filters_item import TrafficReportsFiltersItem
from .traffic_reports_response_200 import TrafficReportsResponse200
from .traffic_reports_response_200_data import TrafficReportsResponse200Data
from .traffic_reports_response_200_data_sources_item import TrafficReportsResponse200DataSourcesItem
from .traffic_reports_response_200_data_sources_item_request_source import (
    TrafficReportsResponse200DataSourcesItemRequestSource,
)
from .traffic_reports_response_200_status import TrafficReportsResponse200Status
from .traffic_reports_response_400 import TrafficReportsResponse400
from .traffic_reports_response_400_data import TrafficReportsResponse400Data
from .traffic_reports_response_400_data_code import TrafficReportsResponse400DataCode
from .traffic_reports_response_400_status import TrafficReportsResponse400Status
from .traffic_reports_response_401 import TrafficReportsResponse401
from .traffic_reports_response_401_data import TrafficReportsResponse401Data
from .traffic_reports_response_401_data_code import TrafficReportsResponse401DataCode
from .traffic_reports_response_401_status import TrafficReportsResponse401Status
from .traffic_reports_response_404 import TrafficReportsResponse404
from .traffic_reports_response_404_data import TrafficReportsResponse404Data
from .traffic_reports_response_404_data_code import TrafficReportsResponse404DataCode
from .traffic_reports_response_404_data_message import TrafficReportsResponse404DataMessage
from .traffic_reports_response_404_status import TrafficReportsResponse404Status
from .traffic_reports_response_500 import TrafficReportsResponse500
from .traffic_reports_response_500_data import TrafficReportsResponse500Data
from .traffic_reports_response_500_data_code import TrafficReportsResponse500DataCode
from .traffic_reports_response_500_status import TrafficReportsResponse500Status
from .update_conversation_json_body import UpdateConversationJsonBody
from .update_conversation_response_200 import UpdateConversationResponse200
from .update_conversation_response_200_data import UpdateConversationResponse200Data
from .update_conversation_response_200_status import UpdateConversationResponse200Status
from .update_conversation_response_400 import UpdateConversationResponse400
from .update_conversation_response_400_data import UpdateConversationResponse400Data
from .update_conversation_response_400_data_code import UpdateConversationResponse400DataCode
from .update_conversation_response_400_status import UpdateConversationResponse400Status
from .update_conversation_response_401 import UpdateConversationResponse401
from .update_conversation_response_401_data import UpdateConversationResponse401Data
from .update_conversation_response_401_data_code import UpdateConversationResponse401DataCode
from .update_conversation_response_401_status import UpdateConversationResponse401Status
from .update_conversation_response_404 import UpdateConversationResponse404
from .update_conversation_response_404_data import UpdateConversationResponse404Data
from .update_conversation_response_404_data_code import UpdateConversationResponse404DataCode
from .update_conversation_response_404_data_message import UpdateConversationResponse404DataMessage
from .update_conversation_response_404_status import UpdateConversationResponse404Status
from .update_conversation_response_500 import UpdateConversationResponse500
from .update_conversation_response_500_data import UpdateConversationResponse500Data
from .update_conversation_response_500_data_code import UpdateConversationResponse500DataCode
from .update_conversation_response_500_status import UpdateConversationResponse500Status
from .update_metadata_json_body import UpdateMetadataJsonBody
from .update_metadata_response_200 import UpdateMetadataResponse200
from .update_metadata_response_200_data import UpdateMetadataResponse200Data
from .update_metadata_response_200_status import UpdateMetadataResponse200Status
from .update_metadata_response_400 import UpdateMetadataResponse400
from .update_metadata_response_400_data import UpdateMetadataResponse400Data
from .update_metadata_response_400_data_code import UpdateMetadataResponse400DataCode
from .update_metadata_response_400_status import UpdateMetadataResponse400Status
from .update_metadata_response_401 import UpdateMetadataResponse401
from .update_metadata_response_401_data import UpdateMetadataResponse401Data
from .update_metadata_response_401_data_code import UpdateMetadataResponse401DataCode
from .update_metadata_response_401_status import UpdateMetadataResponse401Status
from .update_metadata_response_404 import UpdateMetadataResponse404
from .update_metadata_response_404_data import UpdateMetadataResponse404Data
from .update_metadata_response_404_data_code import UpdateMetadataResponse404DataCode
from .update_metadata_response_404_data_message import UpdateMetadataResponse404DataMessage
from .update_metadata_response_404_status import UpdateMetadataResponse404Status
from .update_metadata_response_500 import UpdateMetadataResponse500
from .update_metadata_response_500_data import UpdateMetadataResponse500Data
from .update_metadata_response_500_data_code import UpdateMetadataResponse500DataCode
from .update_metadata_response_500_status import UpdateMetadataResponse500Status
from .update_plugin_json_body import UpdatePluginJsonBody
from .update_plugin_response_200 import UpdatePluginResponse200
from .update_plugin_response_200_data import UpdatePluginResponse200Data
from .update_plugin_response_200_status import UpdatePluginResponse200Status
from .update_plugin_response_400 import UpdatePluginResponse400
from .update_plugin_response_400_data import UpdatePluginResponse400Data
from .update_plugin_response_400_data_code import UpdatePluginResponse400DataCode
from .update_plugin_response_400_status import UpdatePluginResponse400Status
from .update_plugin_response_401 import UpdatePluginResponse401
from .update_plugin_response_401_data import UpdatePluginResponse401Data
from .update_plugin_response_401_data_code import UpdatePluginResponse401DataCode
from .update_plugin_response_401_status import UpdatePluginResponse401Status
from .update_plugin_response_404 import UpdatePluginResponse404
from .update_plugin_response_404_data import UpdatePluginResponse404Data
from .update_plugin_response_404_data_code import UpdatePluginResponse404DataCode
from .update_plugin_response_404_data_message import UpdatePluginResponse404DataMessage
from .update_plugin_response_404_status import UpdatePluginResponse404Status
from .update_plugin_response_500 import UpdatePluginResponse500
from .update_plugin_response_500_data import UpdatePluginResponse500Data
from .update_plugin_response_500_data_code import UpdatePluginResponse500DataCode
from .update_plugin_response_500_status import UpdatePluginResponse500Status
from .update_project_multipart_data import UpdateProjectMultipartData
from .update_project_response_200 import UpdateProjectResponse200
from .update_project_response_200_data import UpdateProjectResponse200Data
from .update_project_response_200_data_type import UpdateProjectResponse200DataType
from .update_project_response_200_status import UpdateProjectResponse200Status
from .update_project_response_400 import UpdateProjectResponse400
from .update_project_response_400_data import UpdateProjectResponse400Data
from .update_project_response_400_data_code import UpdateProjectResponse400DataCode
from .update_project_response_400_status import UpdateProjectResponse400Status
from .update_project_response_401 import UpdateProjectResponse401
from .update_project_response_401_data import UpdateProjectResponse401Data
from .update_project_response_401_data_code import UpdateProjectResponse401DataCode
from .update_project_response_401_status import UpdateProjectResponse401Status
from .update_project_response_404 import UpdateProjectResponse404
from .update_project_response_404_data import UpdateProjectResponse404Data
from .update_project_response_404_data_code import UpdateProjectResponse404DataCode
from .update_project_response_404_data_message import UpdateProjectResponse404DataMessage
from .update_project_response_404_status import UpdateProjectResponse404Status
from .update_project_response_500 import UpdateProjectResponse500
from .update_project_response_500_data import UpdateProjectResponse500Data
from .update_project_response_500_data_code import UpdateProjectResponse500DataCode
from .update_project_response_500_status import UpdateProjectResponse500Status
from .update_project_settings_multipart_data import UpdateProjectSettingsMultipartData
from .update_project_settings_multipart_data_chatbot_model import UpdateProjectSettingsMultipartDataChatbotModel
from .update_project_settings_multipart_data_chatbot_msg_lang import UpdateProjectSettingsMultipartDataChatbotMsgLang
from .update_project_settings_multipart_data_citations_view_type import (
    UpdateProjectSettingsMultipartDataCitationsViewType,
)
from .update_project_settings_multipart_data_enable_citations import UpdateProjectSettingsMultipartDataEnableCitations
from .update_project_settings_multipart_data_response_source import UpdateProjectSettingsMultipartDataResponseSource
from .update_project_settings_response_200 import UpdateProjectSettingsResponse200
from .update_project_settings_response_200_data import UpdateProjectSettingsResponse200Data
from .update_project_settings_response_200_status import UpdateProjectSettingsResponse200Status
from .update_project_settings_response_400 import UpdateProjectSettingsResponse400
from .update_project_settings_response_400_data import UpdateProjectSettingsResponse400Data
from .update_project_settings_response_400_data_code import UpdateProjectSettingsResponse400DataCode
from .update_project_settings_response_400_data_message import UpdateProjectSettingsResponse400DataMessage
from .update_project_settings_response_400_status import UpdateProjectSettingsResponse400Status
from .update_project_settings_response_401 import UpdateProjectSettingsResponse401
from .update_project_settings_response_401_data import UpdateProjectSettingsResponse401Data
from .update_project_settings_response_401_data_code import UpdateProjectSettingsResponse401DataCode
from .update_project_settings_response_401_status import UpdateProjectSettingsResponse401Status
from .update_project_settings_response_500 import UpdateProjectSettingsResponse500
from .update_project_settings_response_500_data import UpdateProjectSettingsResponse500Data
from .update_project_settings_response_500_data_code import UpdateProjectSettingsResponse500DataCode
from .update_project_settings_response_500_status import UpdateProjectSettingsResponse500Status
from .update_source_json_body import UpdateSourceJsonBody
from .update_source_json_body_data_refresh_frequency import UpdateSourceJsonBodyDataRefreshFrequency
from .update_source_json_body_refresh_existing_pages import UpdateSourceJsonBodyRefreshExistingPages
from .update_source_json_body_refresh_schedule_item import UpdateSourceJsonBodyRefreshScheduleItem
from .update_source_response_201 import UpdateSourceResponse201
from .update_source_response_201_data import UpdateSourceResponse201Data
from .update_source_response_201_data_pages_item import UpdateSourceResponse201DataPagesItem
from .update_source_response_201_data_pages_item_crawl_status import UpdateSourceResponse201DataPagesItemCrawlStatus
from .update_source_response_201_data_pages_item_index_status import UpdateSourceResponse201DataPagesItemIndexStatus
from .update_source_response_201_data_settings import UpdateSourceResponse201DataSettings
from .update_source_response_201_data_settings_data_refresh_frequency import (
    UpdateSourceResponse201DataSettingsDataRefreshFrequency,
)
from .update_source_response_201_data_settings_refresh_existing_pages import (
    UpdateSourceResponse201DataSettingsRefreshExistingPages,
)
from .update_source_response_201_data_type import UpdateSourceResponse201DataType
from .update_source_response_201_status import UpdateSourceResponse201Status
from .update_source_response_400 import UpdateSourceResponse400
from .update_source_response_400_data import UpdateSourceResponse400Data
from .update_source_response_400_data_code import UpdateSourceResponse400DataCode
from .update_source_response_400_status import UpdateSourceResponse400Status
from .update_source_response_401 import UpdateSourceResponse401
from .update_source_response_401_data import UpdateSourceResponse401Data
from .update_source_response_401_data_code import UpdateSourceResponse401DataCode
from .update_source_response_401_status import UpdateSourceResponse401Status
from .update_source_response_404 import UpdateSourceResponse404
from .update_source_response_404_data import UpdateSourceResponse404Data
from .update_source_response_404_data_code import UpdateSourceResponse404DataCode
from .update_source_response_404_data_message import UpdateSourceResponse404DataMessage
from .update_source_response_404_status import UpdateSourceResponse404Status
from .update_source_response_500 import UpdateSourceResponse500
from .update_source_response_500_data import UpdateSourceResponse500Data
from .update_source_response_500_data_code import UpdateSourceResponse500DataCode
from .update_source_response_500_status import UpdateSourceResponse500Status
from .update_user_multipart_data import UpdateUserMultipartData
from .update_user_response_200 import UpdateUserResponse200
from .update_user_response_200_data import UpdateUserResponse200Data
from .update_user_response_200_status import UpdateUserResponse200Status
from .update_user_response_401 import UpdateUserResponse401
from .update_user_response_401_data import UpdateUserResponse401Data
from .update_user_response_401_data_code import UpdateUserResponse401DataCode
from .update_user_response_401_status import UpdateUserResponse401Status
from .update_user_response_500 import UpdateUserResponse500
from .update_user_response_500_data import UpdateUserResponse500Data
from .update_user_response_500_data_code import UpdateUserResponse500DataCode
from .update_user_response_500_status import UpdateUserResponse500Status
from .user import User

__all__ = (
    "AnalysisReportsFiltersItem",
    "AnalysisReportsInterval",
    "AnalysisReportsResponse200",
    "AnalysisReportsResponse200Data",
    "AnalysisReportsResponse200DataConversationsItem",
    "AnalysisReportsResponse200DataQueriesItem",
    "AnalysisReportsResponse200DataQueriesPerConversationItem",
    "AnalysisReportsResponse200Status",
    "AnalysisReportsResponse400",
    "AnalysisReportsResponse400Data",
    "AnalysisReportsResponse400DataCode",
    "AnalysisReportsResponse400Status",
    "AnalysisReportsResponse401",
    "AnalysisReportsResponse401Data",
    "AnalysisReportsResponse401DataCode",
    "AnalysisReportsResponse401Status",
    "AnalysisReportsResponse404",
    "AnalysisReportsResponse404Data",
    "AnalysisReportsResponse404DataCode",
    "AnalysisReportsResponse404DataMessage",
    "AnalysisReportsResponse404Status",
    "AnalysisReportsResponse500",
    "AnalysisReportsResponse500Data",
    "AnalysisReportsResponse500DataCode",
    "AnalysisReportsResponse500Status",
    "Conversation",
    "ConversationsReportsFiltersItem",
    "ConversationsReportsResponse200",
    "ConversationsReportsResponse200Data",
    "ConversationsReportsResponse200Status",
    "ConversationsReportsResponse400",
    "ConversationsReportsResponse400Data",
    "ConversationsReportsResponse400DataCode",
    "ConversationsReportsResponse400Status",
    "ConversationsReportsResponse401",
    "ConversationsReportsResponse401Data",
    "ConversationsReportsResponse401DataCode",
    "ConversationsReportsResponse401Status",
    "ConversationsReportsResponse404",
    "ConversationsReportsResponse404Data",
    "ConversationsReportsResponse404DataCode",
    "ConversationsReportsResponse404DataMessage",
    "ConversationsReportsResponse404Status",
    "ConversationsReportsResponse500",
    "ConversationsReportsResponse500Data",
    "ConversationsReportsResponse500DataCode",
    "ConversationsReportsResponse500Status",
    "CreateConversationJsonBody",
    "CreateConversationResponse201",
    "CreateConversationResponse201Data",
    "CreateConversationResponse201Status",
    "CreateConversationResponse400",
    "CreateConversationResponse400Data",
    "CreateConversationResponse400DataCode",
    "CreateConversationResponse400Status",
    "CreateConversationResponse401",
    "CreateConversationResponse401Data",
    "CreateConversationResponse401DataCode",
    "CreateConversationResponse401Status",
    "CreateConversationResponse404",
    "CreateConversationResponse404Data",
    "CreateConversationResponse404DataCode",
    "CreateConversationResponse404DataMessage",
    "CreateConversationResponse404Status",
    "CreateConversationResponse500",
    "CreateConversationResponse500Data",
    "CreateConversationResponse500DataCode",
    "CreateConversationResponse500Status",
    "CreatePluginJsonBody",
    "CreatePluginResponse201",
    "CreatePluginResponse201Data",
    "CreatePluginResponse201Status",
    "CreatePluginResponse400",
    "CreatePluginResponse400Data",
    "CreatePluginResponse400DataCode",
    "CreatePluginResponse400Status",
    "CreatePluginResponse401",
    "CreatePluginResponse401Data",
    "CreatePluginResponse401DataCode",
    "CreatePluginResponse401Status",
    "CreatePluginResponse404",
    "CreatePluginResponse404Data",
    "CreatePluginResponse404DataCode",
    "CreatePluginResponse404DataMessage",
    "CreatePluginResponse404Status",
    "CreatePluginResponse500",
    "CreatePluginResponse500Data",
    "CreatePluginResponse500DataCode",
    "CreatePluginResponse500Status",
    "CreateProjectMultipartData",
    "CreateProjectResponse201",
    "CreateProjectResponse201Data",
    "CreateProjectResponse201DataType",
    "CreateProjectResponse201Status",
    "CreateProjectResponse400",
    "CreateProjectResponse400Data",
    "CreateProjectResponse400DataCode",
    "CreateProjectResponse400DataMessage",
    "CreateProjectResponse400Status",
    "CreateProjectResponse401",
    "CreateProjectResponse401Data",
    "CreateProjectResponse401DataCode",
    "CreateProjectResponse401Status",
    "CreateProjectResponse500",
    "CreateProjectResponse500Data",
    "CreateProjectResponse500DataCode",
    "CreateProjectResponse500Status",
    "CreateSourceMultipartData",
    "CreateSourceResponse201",
    "CreateSourceResponse201Data",
    "CreateSourceResponse201DataPagesItem",
    "CreateSourceResponse201DataPagesItemCrawlStatus",
    "CreateSourceResponse201DataPagesItemIndexStatus",
    "CreateSourceResponse201DataSettings",
    "CreateSourceResponse201DataSettingsDataRefreshFrequency",
    "CreateSourceResponse201DataSettingsRefreshExistingPages",
    "CreateSourceResponse201DataType",
    "CreateSourceResponse201Status",
    "CreateSourceResponse400",
    "CreateSourceResponse400Data",
    "CreateSourceResponse400DataCode",
    "CreateSourceResponse400Status",
    "CreateSourceResponse401",
    "CreateSourceResponse401Data",
    "CreateSourceResponse401DataCode",
    "CreateSourceResponse401Status",
    "CreateSourceResponse404",
    "CreateSourceResponse404Data",
    "CreateSourceResponse404DataCode",
    "CreateSourceResponse404DataMessage",
    "CreateSourceResponse404Status",
    "CreateSourceResponse500",
    "CreateSourceResponse500Data",
    "CreateSourceResponse500DataCode",
    "CreateSourceResponse500Status",
    "DeleteConversationResponse200",
    "DeleteConversationResponse200Data",
    "DeleteConversationResponse200Status",
    "DeleteConversationResponse400",
    "DeleteConversationResponse400Data",
    "DeleteConversationResponse400DataCode",
    "DeleteConversationResponse400Status",
    "DeleteConversationResponse401",
    "DeleteConversationResponse401Data",
    "DeleteConversationResponse401DataCode",
    "DeleteConversationResponse401Status",
    "DeleteConversationResponse404",
    "DeleteConversationResponse404Data",
    "DeleteConversationResponse404DataCode",
    "DeleteConversationResponse404DataMessage",
    "DeleteConversationResponse404Status",
    "DeleteConversationResponse500",
    "DeleteConversationResponse500Data",
    "DeleteConversationResponse500DataCode",
    "DeleteConversationResponse500Status",
    "DeletePageResponse200",
    "DeletePageResponse200Data",
    "DeletePageResponse200Status",
    "DeletePageResponse400",
    "DeletePageResponse400Data",
    "DeletePageResponse400DataCode",
    "DeletePageResponse400Status",
    "DeletePageResponse401",
    "DeletePageResponse401Data",
    "DeletePageResponse401DataCode",
    "DeletePageResponse401Status",
    "DeletePageResponse404",
    "DeletePageResponse404Data",
    "DeletePageResponse404DataCode",
    "DeletePageResponse404DataMessage",
    "DeletePageResponse404Status",
    "DeletePageResponse500",
    "DeletePageResponse500Data",
    "DeletePageResponse500DataCode",
    "DeletePageResponse500Status",
    "DeleteProjectResponse200",
    "DeleteProjectResponse200Data",
    "DeleteProjectResponse200Status",
    "DeleteProjectResponse400",
    "DeleteProjectResponse400Data",
    "DeleteProjectResponse400DataCode",
    "DeleteProjectResponse400Status",
    "DeleteProjectResponse401",
    "DeleteProjectResponse401Data",
    "DeleteProjectResponse401DataCode",
    "DeleteProjectResponse401Status",
    "DeleteProjectResponse404",
    "DeleteProjectResponse404Data",
    "DeleteProjectResponse404DataCode",
    "DeleteProjectResponse404DataMessage",
    "DeleteProjectResponse404Status",
    "DeleteProjectResponse500",
    "DeleteProjectResponse500Data",
    "DeleteProjectResponse500DataCode",
    "DeleteProjectResponse500Status",
    "DeleteSourceResponse200",
    "DeleteSourceResponse200Data",
    "DeleteSourceResponse200Status",
    "DeleteSourceResponse400",
    "DeleteSourceResponse400Data",
    "DeleteSourceResponse400DataCode",
    "DeleteSourceResponse400Status",
    "DeleteSourceResponse401",
    "DeleteSourceResponse401Data",
    "DeleteSourceResponse401DataCode",
    "DeleteSourceResponse401Status",
    "DeleteSourceResponse404",
    "DeleteSourceResponse404Data",
    "DeleteSourceResponse404DataCode",
    "DeleteSourceResponse404DataMessage",
    "DeleteSourceResponse404Status",
    "DeleteSourceResponse500",
    "DeleteSourceResponse500Data",
    "DeleteSourceResponse500DataCode",
    "DeleteSourceResponse500Status",
    "GetApiV1LimitsUsageResponse200",
    "GetApiV1LimitsUsageResponse200Data",
    "GetApiV1LimitsUsageResponse200Status",
    "GetApiV1LimitsUsageResponse401",
    "GetApiV1LimitsUsageResponse401Data",
    "GetApiV1LimitsUsageResponse401DataCode",
    "GetApiV1LimitsUsageResponse401Status",
    "GetApiV1LimitsUsageResponse500",
    "GetApiV1LimitsUsageResponse500Data",
    "GetApiV1LimitsUsageResponse500DataCode",
    "GetApiV1LimitsUsageResponse500Status",
    "GetCitationResponse200",
    "GetCitationResponse200Data",
    "GetCitationResponse200Status",
    "GetCitationResponse400",
    "GetCitationResponse400Data",
    "GetCitationResponse400DataCode",
    "GetCitationResponse400Status",
    "GetCitationResponse401",
    "GetCitationResponse401Data",
    "GetCitationResponse401DataCode",
    "GetCitationResponse401Status",
    "GetCitationResponse404",
    "GetCitationResponse404Data",
    "GetCitationResponse404DataCode",
    "GetCitationResponse404DataMessage",
    "GetCitationResponse404Status",
    "GetConversationsOrder",
    "GetConversationsOrderBy",
    "GetConversationsResponse200",
    "GetConversationsResponse200Data",
    "GetConversationsResponse200DataDataItem",
    "GetConversationsResponse200Status",
    "GetConversationsResponse400",
    "GetConversationsResponse400Data",
    "GetConversationsResponse400DataCode",
    "GetConversationsResponse400Status",
    "GetConversationsResponse401",
    "GetConversationsResponse401Data",
    "GetConversationsResponse401DataCode",
    "GetConversationsResponse401Status",
    "GetConversationsResponse404",
    "GetConversationsResponse404Data",
    "GetConversationsResponse404DataCode",
    "GetConversationsResponse404DataMessage",
    "GetConversationsResponse404Status",
    "GetConversationsResponse500",
    "GetConversationsResponse500Data",
    "GetConversationsResponse500DataCode",
    "GetConversationsResponse500Status",
    "GetConversationsUserFilter",
    "GetMetadataResponse200",
    "GetMetadataResponse200Data",
    "GetMetadataResponse200Status",
    "GetMetadataResponse400",
    "GetMetadataResponse400Data",
    "GetMetadataResponse400DataCode",
    "GetMetadataResponse400Status",
    "GetMetadataResponse401",
    "GetMetadataResponse401Data",
    "GetMetadataResponse401DataCode",
    "GetMetadataResponse401Status",
    "GetMetadataResponse404",
    "GetMetadataResponse404Data",
    "GetMetadataResponse404DataCode",
    "GetMetadataResponse404DataMessage",
    "GetMetadataResponse404Status",
    "GetPagesOrder",
    "GetPagesResponse200",
    "GetPagesResponse200Data",
    "GetPagesResponse200DataPages",
    "GetPagesResponse200DataPagesDataItem",
    "GetPagesResponse200DataPagesDataItemCrawlStatus",
    "GetPagesResponse200DataPagesDataItemIndexStatus",
    "GetPagesResponse200DataProject",
    "GetPagesResponse200DataProjectType",
    "GetPagesResponse200Status",
    "GetPagesResponse400",
    "GetPagesResponse400Data",
    "GetPagesResponse400DataCode",
    "GetPagesResponse400Status",
    "GetPagesResponse401",
    "GetPagesResponse401Data",
    "GetPagesResponse401DataCode",
    "GetPagesResponse401Status",
    "GetPagesResponse404",
    "GetPagesResponse404Data",
    "GetPagesResponse404DataCode",
    "GetPagesResponse404DataMessage",
    "GetPagesResponse404Status",
    "GetPagesResponse500",
    "GetPagesResponse500Data",
    "GetPagesResponse500DataCode",
    "GetPagesResponse500Status",
    "GetPluginResponse200",
    "GetPluginResponse200Data",
    "GetPluginResponse200Status",
    "GetPluginResponse400",
    "GetPluginResponse400Data",
    "GetPluginResponse400DataCode",
    "GetPluginResponse400Status",
    "GetPluginResponse401",
    "GetPluginResponse401Data",
    "GetPluginResponse401DataCode",
    "GetPluginResponse401Status",
    "GetPluginResponse404",
    "GetPluginResponse404Data",
    "GetPluginResponse404DataCode",
    "GetPluginResponse404DataMessage",
    "GetPluginResponse404Status",
    "GetPluginResponse500",
    "GetPluginResponse500Data",
    "GetPluginResponse500DataCode",
    "GetPluginResponse500Status",
    "GetProjectResponse200",
    "GetProjectResponse200Data",
    "GetProjectResponse200DataType",
    "GetProjectResponse200Status",
    "GetProjectResponse400",
    "GetProjectResponse400Data",
    "GetProjectResponse400DataCode",
    "GetProjectResponse400Status",
    "GetProjectResponse401",
    "GetProjectResponse401Data",
    "GetProjectResponse401DataCode",
    "GetProjectResponse401Status",
    "GetProjectResponse404",
    "GetProjectResponse404Data",
    "GetProjectResponse404DataCode",
    "GetProjectResponse404DataMessage",
    "GetProjectResponse404Status",
    "GetProjectResponse500",
    "GetProjectResponse500Data",
    "GetProjectResponse500DataCode",
    "GetProjectResponse500Status",
    "GetProjectSettingsResponse200",
    "GetProjectSettingsResponse200Data",
    "GetProjectSettingsResponse200DataChatbotModel",
    "GetProjectSettingsResponse200DataCitationsViewType",
    "GetProjectSettingsResponse200DataEnableCitations",
    "GetProjectSettingsResponse200DataResponseSource",
    "GetProjectSettingsResponse200Status",
    "GetProjectSettingsResponse400",
    "GetProjectSettingsResponse400Data",
    "GetProjectSettingsResponse400DataCode",
    "GetProjectSettingsResponse400Status",
    "GetProjectSettingsResponse401",
    "GetProjectSettingsResponse401Data",
    "GetProjectSettingsResponse401DataCode",
    "GetProjectSettingsResponse401Status",
    "GetProjectSettingsResponse404",
    "GetProjectSettingsResponse404Data",
    "GetProjectSettingsResponse404DataCode",
    "GetProjectSettingsResponse404DataMessage",
    "GetProjectSettingsResponse404Status",
    "GetProjectSettingsResponse500",
    "GetProjectSettingsResponse500Data",
    "GetProjectSettingsResponse500DataCode",
    "GetProjectSettingsResponse500Status",
    "GetUserResponse200",
    "GetUserResponse200Data",
    "GetUserResponse200Status",
    "GetUserResponse401",
    "GetUserResponse401Data",
    "GetUserResponse401DataCode",
    "GetUserResponse401Status",
    "GetUserResponse500",
    "GetUserResponse500Data",
    "GetUserResponse500DataCode",
    "GetUserResponse500Status",
    "ListProjectsOrder",
    "ListProjectsOrderBy",
    "ListProjectsResponse200",
    "ListProjectsResponse200Data",
    "ListProjectsResponse200DataDataItem",
    "ListProjectsResponse200DataDataItemType",
    "ListProjectsResponse200Status",
    "ListProjectsResponse401",
    "ListProjectsResponse401Data",
    "ListProjectsResponse401DataCode",
    "ListProjectsResponse401Status",
    "ListProjectsResponse500",
    "ListProjectsResponse500Data",
    "ListProjectsResponse500DataCode",
    "ListProjectsResponse500Status",
    "ListSourcesResponse200",
    "ListSourcesResponse200Data",
    "ListSourcesResponse200DataSitemapsItem",
    "ListSourcesResponse200DataSitemapsItemPagesItem",
    "ListSourcesResponse200DataSitemapsItemPagesItemCrawlStatus",
    "ListSourcesResponse200DataSitemapsItemPagesItemIndexStatus",
    "ListSourcesResponse200DataSitemapsItemSettings",
    "ListSourcesResponse200DataSitemapsItemSettingsDataRefreshFrequency",
    "ListSourcesResponse200DataSitemapsItemSettingsRefreshExistingPages",
    "ListSourcesResponse200DataSitemapsItemType",
    "ListSourcesResponse200DataUploads",
    "ListSourcesResponse200DataUploadsPagesItem",
    "ListSourcesResponse200DataUploadsPagesItemCrawlStatus",
    "ListSourcesResponse200DataUploadsPagesItemIndexStatus",
    "ListSourcesResponse200DataUploadsSettings",
    "ListSourcesResponse200DataUploadsSettingsDataRefreshFrequency",
    "ListSourcesResponse200DataUploadsSettingsRefreshExistingPages",
    "ListSourcesResponse200DataUploadsType",
    "ListSourcesResponse200Status",
    "ListSourcesResponse401",
    "ListSourcesResponse401Data",
    "ListSourcesResponse401DataCode",
    "ListSourcesResponse401Status",
    "ListSourcesResponse500",
    "ListSourcesResponse500Data",
    "ListSourcesResponse500DataCode",
    "ListSourcesResponse500Status",
    "MessagesConversationOrder",
    "MessagesConversationResponse200",
    "MessagesConversationResponse200Data",
    "MessagesConversationResponse200DataConversation",
    "MessagesConversationResponse200DataMessages",
    "MessagesConversationResponse200DataMessagesDataItem",
    "MessagesConversationResponse200DataMessagesDataItemMetadata",
    "MessagesConversationResponse200Status",
    "MessagesConversationResponse400",
    "MessagesConversationResponse400Data",
    "MessagesConversationResponse400DataCode",
    "MessagesConversationResponse400Status",
    "MessagesConversationResponse401",
    "MessagesConversationResponse401Data",
    "MessagesConversationResponse401DataCode",
    "MessagesConversationResponse401Status",
    "MessagesConversationResponse404",
    "MessagesConversationResponse404Data",
    "MessagesConversationResponse404DataCode",
    "MessagesConversationResponse404DataMessage",
    "MessagesConversationResponse404Status",
    "MessagesConversationResponse500",
    "MessagesConversationResponse500Data",
    "MessagesConversationResponse500DataCode",
    "MessagesConversationResponse500Status",
    "Page",
    "PageCrawlStatus",
    "PageIndexStatus",
    "PageMetadata",
    "PreviewCitationResponse400",
    "PreviewCitationResponse400Data",
    "PreviewCitationResponse400DataCode",
    "PreviewCitationResponse400Status",
    "PreviewCitationResponse401",
    "PreviewCitationResponse401Data",
    "PreviewCitationResponse401DataCode",
    "PreviewCitationResponse401Status",
    "PreviewCitationResponse404",
    "PreviewCitationResponse404Data",
    "PreviewCitationResponse404DataCode",
    "PreviewCitationResponse404DataMessage",
    "PreviewCitationResponse404Status",
    "PreviewCitationResponse500",
    "PreviewCitationResponse500Data",
    "PreviewCitationResponse500DataCode",
    "PreviewCitationResponse500Status",
    "Project",
    "ProjectAnalyticsAnalysis",
    "ProjectAnalyticsAnalysisConversationsItem",
    "ProjectAnalyticsAnalysisQueriesItem",
    "ProjectAnalyticsAnalysisQueriesPerConversationItem",
    "ProjectAnalyticsConversation",
    "ProjectAnalyticsQuery",
    "ProjectAnalyticsQueryQueryStatusItem",
    "ProjectAnalyticsQueryQueryStatusItemStatus",
    "ProjectAnalyticsTraffic",
    "ProjectAnalyticsTrafficSourcesItem",
    "ProjectAnalyticsTrafficSourcesItemRequestSource",
    "ProjectPlugin",
    "ProjectSettings",
    "ProjectSettingsChatbotModel",
    "ProjectSettingsCitationsViewType",
    "ProjectSettingsEnableCitations",
    "ProjectSettingsResponseSource",
    "ProjectSource",
    "ProjectSourcePagesItem",
    "ProjectSourcePagesItemCrawlStatus",
    "ProjectSourcePagesItemIndexStatus",
    "ProjectSourceSettings",
    "ProjectSourceSettingsDataRefreshFrequency",
    "ProjectSourceSettingsRefreshExistingPages",
    "ProjectSourceType",
    "ProjectType",
    "PromptHistory",
    "PromptHistoryMetadata",
    "QueriesReportsFiltersItem",
    "QueriesReportsResponse200",
    "QueriesReportsResponse200Data",
    "QueriesReportsResponse200DataQueryStatusItem",
    "QueriesReportsResponse200DataQueryStatusItemStatus",
    "QueriesReportsResponse200Status",
    "QueriesReportsResponse400",
    "QueriesReportsResponse400Data",
    "QueriesReportsResponse400DataCode",
    "QueriesReportsResponse400Status",
    "QueriesReportsResponse401",
    "QueriesReportsResponse401Data",
    "QueriesReportsResponse401DataCode",
    "QueriesReportsResponse401Status",
    "QueriesReportsResponse404",
    "QueriesReportsResponse404Data",
    "QueriesReportsResponse404DataCode",
    "QueriesReportsResponse404DataMessage",
    "QueriesReportsResponse404Status",
    "QueriesReportsResponse500",
    "QueriesReportsResponse500Data",
    "QueriesReportsResponse500DataCode",
    "QueriesReportsResponse500Status",
    "ReindexPageResponse200",
    "ReindexPageResponse200Data",
    "ReindexPageResponse200Status",
    "ReindexPageResponse400",
    "ReindexPageResponse400Data",
    "ReindexPageResponse400DataCode",
    "ReindexPageResponse400Status",
    "ReindexPageResponse401",
    "ReindexPageResponse401Data",
    "ReindexPageResponse401DataCode",
    "ReindexPageResponse401Status",
    "ReindexPageResponse403",
    "ReindexPageResponse403Data",
    "ReindexPageResponse403DataCode",
    "ReindexPageResponse403DataMessage",
    "ReindexPageResponse403Status",
    "ReindexPageResponse500",
    "ReindexPageResponse500Data",
    "ReindexPageResponse500DataCode",
    "ReindexPageResponse500Status",
    "ReplicateProjectResponse201",
    "ReplicateProjectResponse201Data",
    "ReplicateProjectResponse201DataType",
    "ReplicateProjectResponse201Status",
    "ReplicateProjectResponse400",
    "ReplicateProjectResponse400Data",
    "ReplicateProjectResponse400DataCode",
    "ReplicateProjectResponse400DataMessage",
    "ReplicateProjectResponse400Status",
    "ReplicateProjectResponse401",
    "ReplicateProjectResponse401Data",
    "ReplicateProjectResponse401DataCode",
    "ReplicateProjectResponse401Status",
    "ReplicateProjectResponse500",
    "ReplicateProjectResponse500Data",
    "ReplicateProjectResponse500DataCode",
    "ReplicateProjectResponse500Status",
    "SendMessageCacheControl",
    "SendMessageJsonBody",
    "SendMessageJsonBodyChatbotModel",
    "SendMessageJsonBodyResponseSource",
    "SendMessageResponse200",
    "SendMessageResponse200Data",
    "SendMessageResponse200DataMetadata",
    "SendMessageResponse200Status",
    "SendMessageResponse400",
    "SendMessageResponse400Data",
    "SendMessageResponse400DataCode",
    "SendMessageResponse400Status",
    "SendMessageResponse401",
    "SendMessageResponse401Data",
    "SendMessageResponse401DataCode",
    "SendMessageResponse401Status",
    "SendMessageResponse404",
    "SendMessageResponse404Data",
    "SendMessageResponse404DataCode",
    "SendMessageResponse404DataMessage",
    "SendMessageResponse404Status",
    "SendMessageResponse429",
    "SendMessageResponse429Data",
    "SendMessageResponse429DataCode",
    "SendMessageResponse429Status",
    "SendMessageResponse500",
    "SendMessageResponse500Data",
    "SendMessageResponse500DataCode",
    "SendMessageResponse500Status",
    "StatsProjectResponse200",
    "StatsProjectResponse200Data",
    "StatsProjectResponse200Status",
    "StatsProjectResponse400",
    "StatsProjectResponse400Data",
    "StatsProjectResponse400DataCode",
    "StatsProjectResponse400Status",
    "StatsProjectResponse401",
    "StatsProjectResponse401Data",
    "StatsProjectResponse401DataCode",
    "StatsProjectResponse401Status",
    "StatsProjectResponse404",
    "StatsProjectResponse404Data",
    "StatsProjectResponse404DataCode",
    "StatsProjectResponse404DataMessage",
    "StatsProjectResponse404Status",
    "StatsProjectResponse500",
    "StatsProjectResponse500Data",
    "StatsProjectResponse500DataCode",
    "StatsProjectResponse500Status",
    "SynchronizeSourceResponse201",
    "SynchronizeSourceResponse201Data",
    "SynchronizeSourceResponse201DataPagesItem",
    "SynchronizeSourceResponse201DataPagesItemCrawlStatus",
    "SynchronizeSourceResponse201DataPagesItemIndexStatus",
    "SynchronizeSourceResponse201DataSettings",
    "SynchronizeSourceResponse201DataSettingsDataRefreshFrequency",
    "SynchronizeSourceResponse201DataSettingsRefreshExistingPages",
    "SynchronizeSourceResponse201DataType",
    "SynchronizeSourceResponse201Status",
    "SynchronizeSourceResponse400",
    "SynchronizeSourceResponse400Data",
    "SynchronizeSourceResponse400DataCode",
    "SynchronizeSourceResponse400Status",
    "SynchronizeSourceResponse401",
    "SynchronizeSourceResponse401Data",
    "SynchronizeSourceResponse401DataCode",
    "SynchronizeSourceResponse401Status",
    "SynchronizeSourceResponse403",
    "SynchronizeSourceResponse403Data",
    "SynchronizeSourceResponse403DataCode",
    "SynchronizeSourceResponse403DataMessage",
    "SynchronizeSourceResponse403Status",
    "SynchronizeSourceResponse404",
    "SynchronizeSourceResponse404Data",
    "SynchronizeSourceResponse404DataCode",
    "SynchronizeSourceResponse404DataMessage",
    "SynchronizeSourceResponse404Status",
    "SynchronizeSourceResponse500",
    "SynchronizeSourceResponse500Data",
    "SynchronizeSourceResponse500DataCode",
    "SynchronizeSourceResponse500Status",
    "Time",
    "TrafficReportsFiltersItem",
    "TrafficReportsResponse200",
    "TrafficReportsResponse200Data",
    "TrafficReportsResponse200DataSourcesItem",
    "TrafficReportsResponse200DataSourcesItemRequestSource",
    "TrafficReportsResponse200Status",
    "TrafficReportsResponse400",
    "TrafficReportsResponse400Data",
    "TrafficReportsResponse400DataCode",
    "TrafficReportsResponse400Status",
    "TrafficReportsResponse401",
    "TrafficReportsResponse401Data",
    "TrafficReportsResponse401DataCode",
    "TrafficReportsResponse401Status",
    "TrafficReportsResponse404",
    "TrafficReportsResponse404Data",
    "TrafficReportsResponse404DataCode",
    "TrafficReportsResponse404DataMessage",
    "TrafficReportsResponse404Status",
    "TrafficReportsResponse500",
    "TrafficReportsResponse500Data",
    "TrafficReportsResponse500DataCode",
    "TrafficReportsResponse500Status",
    "UpdateConversationJsonBody",
    "UpdateConversationResponse200",
    "UpdateConversationResponse200Data",
    "UpdateConversationResponse200Status",
    "UpdateConversationResponse400",
    "UpdateConversationResponse400Data",
    "UpdateConversationResponse400DataCode",
    "UpdateConversationResponse400Status",
    "UpdateConversationResponse401",
    "UpdateConversationResponse401Data",
    "UpdateConversationResponse401DataCode",
    "UpdateConversationResponse401Status",
    "UpdateConversationResponse404",
    "UpdateConversationResponse404Data",
    "UpdateConversationResponse404DataCode",
    "UpdateConversationResponse404DataMessage",
    "UpdateConversationResponse404Status",
    "UpdateConversationResponse500",
    "UpdateConversationResponse500Data",
    "UpdateConversationResponse500DataCode",
    "UpdateConversationResponse500Status",
    "UpdateMetadataJsonBody",
    "UpdateMetadataResponse200",
    "UpdateMetadataResponse200Data",
    "UpdateMetadataResponse200Status",
    "UpdateMetadataResponse400",
    "UpdateMetadataResponse400Data",
    "UpdateMetadataResponse400DataCode",
    "UpdateMetadataResponse400Status",
    "UpdateMetadataResponse401",
    "UpdateMetadataResponse401Data",
    "UpdateMetadataResponse401DataCode",
    "UpdateMetadataResponse401Status",
    "UpdateMetadataResponse404",
    "UpdateMetadataResponse404Data",
    "UpdateMetadataResponse404DataCode",
    "UpdateMetadataResponse404DataMessage",
    "UpdateMetadataResponse404Status",
    "UpdateMetadataResponse500",
    "UpdateMetadataResponse500Data",
    "UpdateMetadataResponse500DataCode",
    "UpdateMetadataResponse500Status",
    "UpdatePluginJsonBody",
    "UpdatePluginResponse200",
    "UpdatePluginResponse200Data",
    "UpdatePluginResponse200Status",
    "UpdatePluginResponse400",
    "UpdatePluginResponse400Data",
    "UpdatePluginResponse400DataCode",
    "UpdatePluginResponse400Status",
    "UpdatePluginResponse401",
    "UpdatePluginResponse401Data",
    "UpdatePluginResponse401DataCode",
    "UpdatePluginResponse401Status",
    "UpdatePluginResponse404",
    "UpdatePluginResponse404Data",
    "UpdatePluginResponse404DataCode",
    "UpdatePluginResponse404DataMessage",
    "UpdatePluginResponse404Status",
    "UpdatePluginResponse500",
    "UpdatePluginResponse500Data",
    "UpdatePluginResponse500DataCode",
    "UpdatePluginResponse500Status",
    "UpdateProjectMultipartData",
    "UpdateProjectResponse200",
    "UpdateProjectResponse200Data",
    "UpdateProjectResponse200DataType",
    "UpdateProjectResponse200Status",
    "UpdateProjectResponse400",
    "UpdateProjectResponse400Data",
    "UpdateProjectResponse400DataCode",
    "UpdateProjectResponse400Status",
    "UpdateProjectResponse401",
    "UpdateProjectResponse401Data",
    "UpdateProjectResponse401DataCode",
    "UpdateProjectResponse401Status",
    "UpdateProjectResponse404",
    "UpdateProjectResponse404Data",
    "UpdateProjectResponse404DataCode",
    "UpdateProjectResponse404DataMessage",
    "UpdateProjectResponse404Status",
    "UpdateProjectResponse500",
    "UpdateProjectResponse500Data",
    "UpdateProjectResponse500DataCode",
    "UpdateProjectResponse500Status",
    "UpdateProjectSettingsMultipartData",
    "UpdateProjectSettingsMultipartDataChatbotModel",
    "UpdateProjectSettingsMultipartDataChatbotMsgLang",
    "UpdateProjectSettingsMultipartDataCitationsViewType",
    "UpdateProjectSettingsMultipartDataEnableCitations",
    "UpdateProjectSettingsMultipartDataResponseSource",
    "UpdateProjectSettingsResponse200",
    "UpdateProjectSettingsResponse200Data",
    "UpdateProjectSettingsResponse200Status",
    "UpdateProjectSettingsResponse400",
    "UpdateProjectSettingsResponse400Data",
    "UpdateProjectSettingsResponse400DataCode",
    "UpdateProjectSettingsResponse400DataMessage",
    "UpdateProjectSettingsResponse400Status",
    "UpdateProjectSettingsResponse401",
    "UpdateProjectSettingsResponse401Data",
    "UpdateProjectSettingsResponse401DataCode",
    "UpdateProjectSettingsResponse401Status",
    "UpdateProjectSettingsResponse500",
    "UpdateProjectSettingsResponse500Data",
    "UpdateProjectSettingsResponse500DataCode",
    "UpdateProjectSettingsResponse500Status",
    "UpdateSourceJsonBody",
    "UpdateSourceJsonBodyDataRefreshFrequency",
    "UpdateSourceJsonBodyRefreshExistingPages",
    "UpdateSourceJsonBodyRefreshScheduleItem",
    "UpdateSourceResponse201",
    "UpdateSourceResponse201Data",
    "UpdateSourceResponse201DataPagesItem",
    "UpdateSourceResponse201DataPagesItemCrawlStatus",
    "UpdateSourceResponse201DataPagesItemIndexStatus",
    "UpdateSourceResponse201DataSettings",
    "UpdateSourceResponse201DataSettingsDataRefreshFrequency",
    "UpdateSourceResponse201DataSettingsRefreshExistingPages",
    "UpdateSourceResponse201DataType",
    "UpdateSourceResponse201Status",
    "UpdateSourceResponse400",
    "UpdateSourceResponse400Data",
    "UpdateSourceResponse400DataCode",
    "UpdateSourceResponse400Status",
    "UpdateSourceResponse401",
    "UpdateSourceResponse401Data",
    "UpdateSourceResponse401DataCode",
    "UpdateSourceResponse401Status",
    "UpdateSourceResponse404",
    "UpdateSourceResponse404Data",
    "UpdateSourceResponse404DataCode",
    "UpdateSourceResponse404DataMessage",
    "UpdateSourceResponse404Status",
    "UpdateSourceResponse500",
    "UpdateSourceResponse500Data",
    "UpdateSourceResponse500DataCode",
    "UpdateSourceResponse500Status",
    "UpdateUserMultipartData",
    "UpdateUserResponse200",
    "UpdateUserResponse200Data",
    "UpdateUserResponse200Status",
    "UpdateUserResponse401",
    "UpdateUserResponse401Data",
    "UpdateUserResponse401DataCode",
    "UpdateUserResponse401Status",
    "UpdateUserResponse500",
    "UpdateUserResponse500Data",
    "UpdateUserResponse500DataCode",
    "UpdateUserResponse500Status",
    "User",
)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.analysis_reports_response_200_data_conversations_item import (
        AnalysisReportsResponse200DataConversationsItem,
    )
    from ..models.analysis_reports_response_200_data_queries_item import AnalysisReportsResponse200DataQueriesItem
    from ..models.analysis_reports_response_200_data_queries_per_conversation_item import (
        AnalysisReportsResponse200DataQueriesPerConversationItem,
    )


T = TypeVar("T", bound="AnalysisReportsResponse200Data")


@attr.s(auto_attribs=True)
class AnalysisReportsResponse200Data:
    """
    Attributes:
        queries (Union[Unset, List['AnalysisReportsResponse200DataQueriesItem']]):
        conversations (Union[Unset, List['AnalysisReportsResponse200DataConversationsItem']]):
        queries_per_conversation (Union[Unset, List['AnalysisReportsResponse200DataQueriesPerConversationItem']]):
    """

    queries: Union[Unset, List["AnalysisReportsResponse200DataQueriesItem"]] = UNSET
    conversations: Union[Unset, List["AnalysisReportsResponse200DataConversationsItem"]] = UNSET
    queries_per_conversation: Union[Unset, List["AnalysisReportsResponse200DataQueriesPerConversationItem"]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        queries: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.queries, Unset):
            queries = []
            for queries_item_data in self.queries:
                queries_item = queries_item_data.to_dict()

                queries.append(queries_item)

        conversations: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.conversations, Unset):
            conversations = []
            for conversations_item_data in self.conversations:
                conversations_item = conversations_item_data.to_dict()

                conversations.append(conversations_item)

        queries_per_conversation: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.queries_per_conversation, Unset):
            queries_per_conversation = []
            for queries_per_conversation_item_data in self.queries_per_conversation:
                queries_per_conversation_item = queries_per_conversation_item_data.to_dict()

                queries_per_conversation.append(queries_per_conversation_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if queries is not UNSET:
            for index, field_value in enumerate(queries):
                field_dict[f"queries[{index}]"] = field_value
        if conversations is not UNSET:
            for index, field_value in enumerate(conversations):
                field_dict[f"conversations[{index}]"] = field_value
        if queries_per_conversation is not UNSET:
            for index, field_value in enumerate(queries_per_conversation):
                field_dict[f"queries_per_conversation[{index}]"] = field_value

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.analysis_reports_response_200_data_conversations_item import (
            AnalysisReportsResponse200DataConversationsItem,
        )
        from ..models.analysis_reports_response_200_data_queries_item import AnalysisReportsResponse200DataQueriesItem
        from ..models.analysis_reports_response_200_data_queries_per_conversation_item import (
            AnalysisReportsResponse200DataQueriesPerConversationItem,
        )

        queries = []
        _queries = src_dict.get("queries")
        for queries_item_data in _queries or []:
            queries_item = AnalysisReportsResponse200DataQueriesItem.from_dict(queries_item_data)

            queries.append(queries_item)

        conversations = []
        _conversations = src_dict.get("conversations")
        for conversations_item_data in _conversations or []:
            conversations_item = AnalysisReportsResponse200DataConversationsItem.from_dict(conversations_item_data)

            conversations.append(conversations_item)

        queries_per_conversation = []
        _queries_per_conversation = src_dict.get("queries_per_conversation")
        for queries_per_conversation_item_data in _queries_per_conversation or []:
            queries_per_conversation_item = AnalysisReportsResponse200DataQueriesPerConversationItem.from_dict(
                queries_per_conversation_item_data
            )

            queries_per_conversation.append(queries_per_conversation_item)

        analysis_reports_response_200_data = cls(
            queries=queries,
            conversations=conversations,
            queries_per_conversation=queries_per_conversation,
        )

        analysis_reports_response_200_data.additional_properties = src_dict
        return analysis_reports_response_200_data

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import json
from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union

import requests

from ... import errors
from ...models.traffic_reports_filters_item import TrafficReportsFiltersItem
from ...models.traffic_reports_response_200 import TrafficReportsResponse200
from ...models.traffic_reports_response_400 import TrafficReportsResponse400
from ...models.traffic_reports_response_401 import TrafficReportsResponse401
from ...models.traffic_reports_response_404 import TrafficReportsResponse404
from ...models.traffic_reports_response_500 import TrafficReportsResponse500
from ...types import UNSET, Response


def _get_kwargs(
    project_id: int,
    *,
    client: {},
    filters: List[TrafficReportsFiltersItem],
) -> Dict[str, Any]:
    url = "{}/api/v1/projects/{projectId}/reports/traffic".format(client.base_url, projectId=project_id)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    json_filters = []
    for filters_item_data in filters:
        filters_item = filters_item_data

        json_filters.append(filters_item)

    params["filters"] = json_filters

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "allow_redirects": client.follow_redirects,
        "params": params,
    }


def _parse_response(*, client: {}, response: None) -> Optional[
    Union[
        TrafficReportsResponse200,
        TrafficReportsResponse400,
        TrafficReportsResponse401,
        TrafficReportsResponse404,
        TrafficReportsResponse500,
    ]
]:
    if response.status_code == HTTPStatus.OK:
        response_200 = TrafficReportsResponse200.from_dict(json.loads(response.text))

        return response_200
    if response.status_code == HTTPStatus.BAD_REQUEST:
        response_400 = TrafficReportsResponse400.from_dict(json.loads(response.text))

        return response_400
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = TrafficReportsResponse401.from_dict(json.loads(response.text))

        return response_401
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = TrafficReportsResponse404.from_dict(json.loads(response.text))

        return response_404
    if response.status_code == HTTPStatus.INTERNAL_SERVER_ERROR:
        response_500 = TrafficReportsResponse500.from_dict(json.loads(response.text))

        return response_500
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: {}, response: None, content: Optional[bytes] = None) -> Response[
    Union[
        TrafficReportsResponse200,
        TrafficReportsResponse400,
        TrafficReportsResponse401,
        TrafficReportsResponse404,
        TrafficReportsResponse500,
    ]
]:
    parse = _parse_response(client=client, response=response)
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content if content is None else content,
        headers=response.headers,
        parsed=parse,
    )


def sync_detailed(
    project_id: int,
    *,
    client: {},
    filters: List[TrafficReportsFiltersItem],
):
    """Provide summary of various metrics of users interactions with the application.

     Provide summary of various metrics of users interactions with the application such as the users
    number (both named and anonymous),
    their geographical locations, the browsers they use, and the sources from which they arrived at the
    application.

    Args:
        project_id (int):  Example: 1.
        filters (List[TrafficReportsFiltersItem]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[TrafficReportsResponse200, TrafficReportsResponse400, TrafficReportsResponse401, TrafficReportsResponse404, TrafficReportsResponse500]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        client=client,
        filters=filters,
    )

    response = requests.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_id: int,
    *,
    client: {},
    filters: List[TrafficReportsFiltersItem],
) -> Optional[
    Union[
        TrafficReportsResponse200,
        TrafficReportsResponse400,
        TrafficReportsResponse401,
        TrafficReportsResponse404,
        TrafficReportsResponse500,
    ]
]:
    """Provide summary of various metrics of users interactions with the application.

     Provide summary of various metrics of users interactions with the application such as the users
    number (both named and anonymous),
    their geographical locations, the browsers they use, and the sources from which they arrived at the
    application.

    Args:
        project_id (int):  Example: 1.
        filters (List[TrafficReportsFiltersItem]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[TrafficReportsResponse200, TrafficReportsResponse400, TrafficReportsResponse401, TrafficReportsResponse404, TrafficReportsResponse500]
    """

    return sync_detailed(
        project_id=project_id,
        client=client,
        filters=filters,
    ).parsed


async def asyncio_detailed(
    project_id: int,
    *,
    client: {},
    filters: List[TrafficReportsFiltersItem],
) -> Response[
    Union[
        TrafficReportsResponse200,
        TrafficReportsResponse400,
        TrafficReportsResponse401,
        TrafficReportsResponse404,
        TrafficReportsResponse500,
    ]
]:

    kwargs = _get_kwargs(
        project_id=project_id,
        client=client,
        filters=filters,
    )

    response = requests.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: int,
    *,
    client: {},
    filters: List[TrafficReportsFiltersItem],
) -> Optional[
    Union[
        TrafficReportsResponse200,
        TrafficReportsResponse400,
        TrafficReportsResponse401,
        TrafficReportsResponse404,
        TrafficReportsResponse500,
    ]
]:
    """Provide summary of various metrics of users interactions with the application.

     Provide summary of various metrics of users interactions with the application such as the users
    number (both named and anonymous),
    their geographical locations, the browsers they use, and the sources from which they arrived at the
    application.

    Args:
        project_id (int):  Example: 1.
        filters (List[TrafficReportsFiltersItem]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[TrafficReportsResponse200, TrafficReportsResponse400, TrafficReportsResponse401, TrafficReportsResponse404, TrafficReportsResponse500]
    """

    return (
        await asyncio_detailed(
            project_id=project_id,
            client=client,
            filters=filters,
        )
    ).parsed



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="GetPagesResponse200DataPagesDataItem")


@attr.s(auto_attribs=True)
class GetPagesResponse200DataPagesDataItem:
    r"""
    Attributes:
        id (Union[Unset, int]): Page ID Example: 1.
        page_url (Union[Unset, str]): URL of the page or file Example: https://example.com.
        page_url_hash (Union[Unset, str]): Hash of the URL of the page or file Example:
            d41d8cd98f00b204e9800998ecf8427e.
        project_id (Union[Unset, int]): Project ID Example: 1.
        s3_path (Union[Unset, None, str]): This is the path where the page is stored in S3.\nNote: This is omitted in
            the response if the page is not a file Example: project-1/page-1/file.pdf.
        crawl_status (Union[Unset, GetPagesResponse200DataPagesDataItemCrawlStatus]): Crawl status of the page Default:
            GetPagesResponse200DataPagesDataItemCrawlStatus.QUEUED. Example: queued.
        index_status (Union[Unset, GetPagesResponse200DataPagesDataItemIndexStatus]): Index status of the page Default:
            GetPagesResponse200DataPagesDataItemIndexStatus.QUEUED. Example: queued.
        is_file (Union[Unset, bool]): Whether the page is a file or not Example: True.
        is_refreshable (Union[Unset, bool]): Whether the page can be refreshed or not Example: True.
        is_file_kept (Union[Unset, bool]): Whether the file is kept after processing or not.\nNote: This is omitted in
            the response if the page is not a file Default: True. Example: True.
        filename (Union[Unset, None, str]): Filename of the page.\nNote: This is omitted in the response if the page is
            not a file Example: file.pdf.
        filesize (Union[Unset, None, int]): Filesize of the page.\nNote: This is omitted in the response if the page is
            not a file Example: 100.
        created_at (Union[Unset, datetime.datetime]): Date and time when the page was created Example: 2021-01-01
            00:00:00.
        updated_at (Union[Unset, datetime.datetime]): Date and time when the page was updated Example: 2021-01-01
            00:00:00.
    """

    id: Union[Unset, int] = UNSET
    page_url: Union[Unset, str] = UNSET
    page_url_hash: Union[Unset, str] = UNSET
    project_id: Union[Unset, int] = UNSET
    s3_path: Union[Unset, None, str] = UNSET
    crawl_status: Union[Unset, str] = UNSET
    index_status: Union[Unset, str] = UNSET
    is_file: Union[Unset, bool] = False
    is_refreshable: Union[Unset, bool] = False
    is_file_kept: Union[Unset, bool] = True
    filename: Union[Unset, None, str] = UNSET
    filesize: Union[Unset, None, int] = UNSET
    created_at: Union[Unset, datetime.datetime] = UNSET
    updated_at: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        page_url = self.page_url
        page_url_hash = self.page_url_hash
        project_id = self.project_id
        s3_path = self.s3_path
        crawl_status: Union[Unset, str] = UNSET
        if not isinstance(self.crawl_status, Unset):
            crawl_status = self.crawl_status

        index_status: Union[Unset, str] = UNSET
        if not isinstance(self.index_status, Unset):
            index_status = self.index_status

        is_file = True if self.is_file else False

        is_refreshable = True if self.is_refreshable else False

        is_file_kept = True if self.is_file_kept else False

        filename = self.filename
        filesize = self.filesize
        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if page_url is not UNSET:
            field_dict["page_url"] = page_url
        if page_url_hash is not UNSET:
            field_dict["page_url_hash"] = page_url_hash
        if project_id is not UNSET:
            field_dict["project_id"] = project_id
        if s3_path is not UNSET:
            field_dict["s3_path"] = s3_path
        if crawl_status is not UNSET:
            field_dict["crawl_status"] = crawl_status
        if index_status is not UNSET:
            field_dict["index_status"] = index_status
        if is_file is not UNSET:
            field_dict["is_file"] = is_file
        if is_refreshable is not UNSET:
            field_dict["is_refreshable"] = is_refreshable
        if is_file_kept is not UNSET:
            field_dict["is_file_kept"] = is_file_kept
        if filename is not UNSET:
            field_dict["filename"] = filename
        if filesize is not UNSET:
            field_dict["filesize"] = filesize
        if created_at is not UNSET:
            field_dict["created_at"] = created_at
        if updated_at is not UNSET:
            field_dict["updated_at"] = updated_at

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        id = src_dict.get("id")

        page_url = src_dict.get("page_url")

        page_url_hash = src_dict.get("page_url_hash")

        project_id = src_dict.get("project_id")

        s3_path = src_dict.get("s3_path")

        crawl_status = src_dict.get("crawl_status")

        index_status = src_dict.get("index_status")

        is_file = src_dict.get("is_file")

        is_refreshable = src_dict.get("is_refreshable")

        is_file_kept = src_dict.get("is_file_kept")

        filename = src_dict.get("filename")

        filesize = src_dict.get("filesize")

        _created_at = src_dict.get("created_at")
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = src_dict.get("updated_at")
        updated_at: Union[Unset, datetime.datetime]
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        get_pages_response_200_data_pages_data_item = cls(
            id=id,
            page_url=page_url,
            page_url_hash=page_url_hash,
            project_id=project_id,
            s3_path=s3_path,
            crawl_status=crawl_status,
            index_status=index_status,
            is_file=is_file,
            is_refreshable=is_refreshable,
            is_file_kept=is_file_kept,
            filename=filename,
            filesize=filesize,
            created_at=created_at,
            updated_at=updated_at,
        )

        get_pages_response_200_data_pages_data_item.additional_properties = src_dict
        return get_pages_response_200_data_pages_data_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import json
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import requests

from ... import errors
from ...models.update_user_multipart_data import UpdateUserMultipartData
from ...models.update_user_response_200 import UpdateUserResponse200
from ...models.update_user_response_401 import UpdateUserResponse401
from ...models.update_user_response_500 import UpdateUserResponse500
from ...types import Response


def _get_kwargs(
    *,
    client: {},
    multipart_data: UpdateUserMultipartData,
) -> Dict[str, Any]:
    url = "{}/api/v1/user".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    multipart_multipart_data = multipart_data.to_multipart()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "allow_redirects": client.follow_redirects,
        "files": multipart_multipart_data,
    }


def _parse_response(
    *, client: {}, response: None
) -> Optional[Union[UpdateUserResponse200, UpdateUserResponse401, UpdateUserResponse500]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = UpdateUserResponse200.from_dict(json.loads(response.text))

        return response_200
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = UpdateUserResponse401.from_dict(json.loads(response.text))

        return response_401
    if response.status_code == HTTPStatus.INTERNAL_SERVER_ERROR:
        response_500 = UpdateUserResponse500.from_dict(json.loads(response.text))

        return response_500
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: {}, response: None, content: Optional[bytes] = None
) -> Response[Union[UpdateUserResponse200, UpdateUserResponse401, UpdateUserResponse500]]:
    parse = _parse_response(client=client, response=response)
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content if content is None else content,
        headers=response.headers,
        parsed=parse,
    )


def sync_detailed(
    *,
    client: {},
    multipart_data: UpdateUserMultipartData,
):
    """Update the user's profile.

     Update the profile of the current user. This endpoint allows the user to modify and update their
    profile information and preferences within the application or system.

    Args:
        multipart_data (UpdateUserMultipartData):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[UpdateUserResponse200, UpdateUserResponse401, UpdateUserResponse500]]
    """

    kwargs = _get_kwargs(
        client=client,
        multipart_data=multipart_data,
    )

    response = requests.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: {},
    multipart_data: UpdateUserMultipartData,
) -> Optional[Union[UpdateUserResponse200, UpdateUserResponse401, UpdateUserResponse500]]:
    """Update the user's profile.

     Update the profile of the current user. This endpoint allows the user to modify and update their
    profile information and preferences within the application or system.

    Args:
        multipart_data (UpdateUserMultipartData):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[UpdateUserResponse200, UpdateUserResponse401, UpdateUserResponse500]
    """

    return sync_detailed(
        client=client,
        multipart_data=multipart_data,
    ).parsed


async def asyncio_detailed(
    *,
    client: {},
    multipart_data: UpdateUserMultipartData,
) -> Response[Union[UpdateUserResponse200, UpdateUserResponse401, UpdateUserResponse500]]:

    kwargs = _get_kwargs(
        client=client,
        multipart_data=multipart_data,
    )

    response = requests.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: {},
    multipart_data: UpdateUserMultipartData,
) -> Optional[Union[UpdateUserResponse200, UpdateUserResponse401, UpdateUserResponse500]]:
    """Update the user's profile.

     Update the profile of the current user. This endpoint allows the user to modify and update their
    profile information and preferences within the application or system.

    Args:
        multipart_data (UpdateUserMultipartData):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[UpdateUserResponse200, UpdateUserResponse401, UpdateUserResponse500]
    """

    return (
        await asyncio_detailed(
            client=client,
            multipart_data=multipart_data,
        )
    ).parsed



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="GetApiV1LimitsUsageResponse200Data")


@attr.s(auto_attribs=True)
class GetApiV1LimitsUsageResponse200Data:
    """
    Attributes:
        max_projects_num (Union[Unset, int]): The maximum number of projects allowed for this team. Example: 10.
        current_projects_num (Union[Unset, int]): The total number of projects currently belonging to this team.
            Example: 10.
        max_total_storage_credits (Union[Unset, int]): The maximum number of storage credits allowed for this team.
            Example: 10.
        current_total_storage_credits (Union[Unset, int]): The amount of storage credits currently in use. Example: 10.
        max_queries (Union[Unset, int]): The maximum number of queries allowed per billing cycle for this team. Example:
            10.
        current_queries (Union[Unset, int]): The number of queries used in the current billing cycle. Example: 10.
    """

    max_projects_num: Union[Unset, int] = UNSET
    current_projects_num: Union[Unset, int] = UNSET
    max_total_storage_credits: Union[Unset, int] = UNSET
    current_total_storage_credits: Union[Unset, int] = UNSET
    max_queries: Union[Unset, int] = UNSET
    current_queries: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        max_projects_num = self.max_projects_num
        current_projects_num = self.current_projects_num
        max_total_storage_credits = self.max_total_storage_credits
        current_total_storage_credits = self.current_total_storage_credits
        max_queries = self.max_queries
        current_queries = self.current_queries

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if max_projects_num is not UNSET:
            field_dict["max_projects_num"] = max_projects_num
        if current_projects_num is not UNSET:
            field_dict["current_projects_num"] = current_projects_num
        if max_total_storage_credits is not UNSET:
            field_dict["max_total_storage_credits"] = max_total_storage_credits
        if current_total_storage_credits is not UNSET:
            field_dict["current_total_storage_credits"] = current_total_storage_credits
        if max_queries is not UNSET:
            field_dict["max_queries"] = max_queries
        if current_queries is not UNSET:
            field_dict["current_queries"] = current_queries

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        max_projects_num = src_dict.get("max_projects_num")

        current_projects_num = src_dict.get("current_projects_num")

        max_total_storage_credits = src_dict.get("max_total_storage_credits")

        current_total_storage_credits = src_dict.get("current_total_storage_credits")

        max_queries = src_dict.get("max_queries")

        current_queries = src_dict.get("current_queries")

        get_api_v1_limits_usage_response_200_data = cls(
            max_projects_num=max_projects_num,
            current_projects_num=current_projects_num,
            max_total_storage_credits=max_total_storage_credits,
            current_total_storage_credits=current_total_storage_credits,
            max_queries=max_queries,
            current_queries=current_queries,
        )

        get_api_v1_limits_usage_response_200_data.additional_properties = src_dict
        return get_api_v1_limits_usage_response_200_data

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.get_pages_response_200_data_pages import GetPagesResponse200DataPages
    from ..models.get_pages_response_200_data_project import GetPagesResponse200DataProject


T = TypeVar("T", bound="GetPagesResponse200Data")


@attr.s(auto_attribs=True)
class GetPagesResponse200Data:
    """
    Attributes:
        project (Union[Unset, GetPagesResponse200DataProject]):
        pages (Union[Unset, GetPagesResponse200DataPages]):
    """

    project: Union[Unset, "GetPagesResponse200DataProject"] = UNSET
    pages: Union[Unset, "GetPagesResponse200DataPages"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        project: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.project, Unset):
            project = self.project.to_dict()

        pages: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.pages, Unset):
            pages = self.pages.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if project is not UNSET:
            field_dict["project"] = project
        if pages is not UNSET:
            field_dict["pages"] = pages

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.get_pages_response_200_data_pages import GetPagesResponse200DataPages
        from ..models.get_pages_response_200_data_project import GetPagesResponse200DataProject

        _project = src_dict.get("project")
        project: Union[Unset, GetPagesResponse200DataProject]
        if isinstance(_project, Unset):
            project = UNSET
        else:
            project = GetPagesResponse200DataProject.from_dict(_project)

        _pages = src_dict.get("pages")
        pages: Union[Unset, GetPagesResponse200DataPages]
        if isinstance(_pages, Unset):
            pages = UNSET
        else:
            pages = GetPagesResponse200DataPages.from_dict(_pages)

        get_pages_response_200_data = cls(
            project=project,
            pages=pages,
        )

        get_pages_response_200_data.additional_properties = src_dict
        return get_pages_response_200_data

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="GetUserResponse200Data")


@attr.s(auto_attribs=True)
class GetUserResponse200Data:
    """
    Attributes:
        created_at (Union[Unset, datetime.datetime]): When was this user created? Example: 2023-04-30 16:43:53.
        email (Union[Unset, str]): User email Example: user@domain.com.
        id (Union[Unset, int]): User ID Example: 1.
        current_team_id (Union[Unset, int]): User currently active team ID Example: 1.
        name (Union[Unset, str]): User name Example: John Doe.
        profile_photo_url (Union[Unset, str]): User profile photo URL Example:
            https://app.customgpt.ai/user/1/profile_photo_url.
        updated_at (Union[Unset, datetime.datetime]): When was this user updated? Example: 2023-04-30 16:43:53.
    """

    created_at: Union[Unset, datetime.datetime] = UNSET
    email: Union[Unset, str] = UNSET
    id: Union[Unset, int] = UNSET
    current_team_id: Union[Unset, int] = UNSET
    name: Union[Unset, str] = UNSET
    profile_photo_url: Union[Unset, str] = UNSET
    updated_at: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        email = self.email
        id = self.id
        current_team_id = self.current_team_id
        name = self.name
        profile_photo_url = self.profile_photo_url
        updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if created_at is not UNSET:
            field_dict["created_at"] = created_at
        if email is not UNSET:
            field_dict["email"] = email
        if id is not UNSET:
            field_dict["id"] = id
        if current_team_id is not UNSET:
            field_dict["current_team_id"] = current_team_id
        if name is not UNSET:
            field_dict["name"] = name
        if profile_photo_url is not UNSET:
            field_dict["profile_photo_url"] = profile_photo_url
        if updated_at is not UNSET:
            field_dict["updated_at"] = updated_at

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        _created_at = src_dict.get("created_at")
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        email = src_dict.get("email")

        id = src_dict.get("id")

        current_team_id = src_dict.get("current_team_id")

        name = src_dict.get("name")

        profile_photo_url = src_dict.get("profile_photo_url")

        _updated_at = src_dict.get("updated_at")
        updated_at: Union[Unset, datetime.datetime]
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        get_user_response_200_data = cls(
            created_at=created_at,
            email=email,
            id=id,
            current_team_id=current_team_id,
            name=name,
            profile_photo_url=profile_photo_url,
            updated_at=updated_at,
        )

        get_user_response_200_data.additional_properties = src_dict
        return get_user_response_200_data

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class ConversationsReportsFiltersItem(str, Enum):
    AVERAGE_QUERIES_PER_CONVERSATION = "average_queries_per_conversation"
    TOTAL = "total"

    def __str__(self) -> str:
        return str(self.value)



import json
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import requests

from ... import errors
from ...models.create_project_multipart_data import CreateProjectMultipartData
from ...models.create_project_response_201 import CreateProjectResponse201
from ...models.create_project_response_400 import CreateProjectResponse400
from ...models.create_project_response_401 import CreateProjectResponse401
from ...models.create_project_response_500 import CreateProjectResponse500
from ...types import Response


def _get_kwargs(
    *,
    client: {},
    multipart_data: CreateProjectMultipartData,
) -> Dict[str, Any]:
    url = "{}/api/v1/projects".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    multipart_multipart_data = multipart_data.to_multipart()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "allow_redirects": client.follow_redirects,
        "files": multipart_multipart_data,
    }


def _parse_response(
    *, client: {}, response: None
) -> Optional[
    Union[CreateProjectResponse201, CreateProjectResponse400, CreateProjectResponse401, CreateProjectResponse500]
]:
    if response.status_code == HTTPStatus.CREATED:
        response_201 = CreateProjectResponse201.from_dict(json.loads(response.text))

        return response_201
    if response.status_code == HTTPStatus.BAD_REQUEST:
        response_400 = CreateProjectResponse400.from_dict(json.loads(response.text))

        return response_400
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = CreateProjectResponse401.from_dict(json.loads(response.text))

        return response_401
    if response.status_code == HTTPStatus.INTERNAL_SERVER_ERROR:
        response_500 = CreateProjectResponse500.from_dict(json.loads(response.text))

        return response_500
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: {}, response: None, content: Optional[bytes] = None
) -> Response[
    Union[CreateProjectResponse201, CreateProjectResponse400, CreateProjectResponse401, CreateProjectResponse500]
]:
    parse = _parse_response(client=client, response=response)
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content if content is None else content,
        headers=response.headers,
        parsed=parse,
    )


def sync_detailed(
    *,
    client: {},
    multipart_data: CreateProjectMultipartData,
):
    """Create a new project.

     Create a new project by importing data either from a sitemap or an uploaded file. This endpoint
    enables you to initiate the creation of a new project by supplying the necessary project data that
    will be used as the context. You can choose to import the project structure and content from a
    sitemap url or upload a specific file format that contains the context can be any text, audio or
    video format. The system will process the provided data and generate a new project based on the
    imported or uploaded information.
    Here is an example to create a bot using a sitemap: [API](https://github.com/Poll-The-
    People/customgpt-cookbook/blob/main/examples/Create_Bot_By_Sitemap.ipynb)
    [SDK](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/SDK_Create_Bot_By_Sitemap.ipynb).

    Args:
        multipart_data (CreateProjectMultipartData):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[CreateProjectResponse201, CreateProjectResponse400, CreateProjectResponse401, CreateProjectResponse500]]
    """

    kwargs = _get_kwargs(
        client=client,
        multipart_data=multipart_data,
    )

    response = requests.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: {},
    multipart_data: CreateProjectMultipartData,
) -> Optional[
    Union[CreateProjectResponse201, CreateProjectResponse400, CreateProjectResponse401, CreateProjectResponse500]
]:
    """Create a new project.

     Create a new project by importing data either from a sitemap or an uploaded file. This endpoint
    enables you to initiate the creation of a new project by supplying the necessary project data that
    will be used as the context. You can choose to import the project structure and content from a
    sitemap url or upload a specific file format that contains the context can be any text, audio or
    video format. The system will process the provided data and generate a new project based on the
    imported or uploaded information.
    Here is an example to create a bot using a sitemap: [API](https://github.com/Poll-The-
    People/customgpt-cookbook/blob/main/examples/Create_Bot_By_Sitemap.ipynb)
    [SDK](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/SDK_Create_Bot_By_Sitemap.ipynb).

    Args:
        multipart_data (CreateProjectMultipartData):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[CreateProjectResponse201, CreateProjectResponse400, CreateProjectResponse401, CreateProjectResponse500]
    """

    return sync_detailed(
        client=client,
        multipart_data=multipart_data,
    ).parsed


async def asyncio_detailed(
    *,
    client: {},
    multipart_data: CreateProjectMultipartData,
) -> Response[
    Union[CreateProjectResponse201, CreateProjectResponse400, CreateProjectResponse401, CreateProjectResponse500]
]:

    kwargs = _get_kwargs(
        client=client,
        multipart_data=multipart_data,
    )

    response = requests.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: {},
    multipart_data: CreateProjectMultipartData,
) -> Optional[
    Union[CreateProjectResponse201, CreateProjectResponse400, CreateProjectResponse401, CreateProjectResponse500]
]:
    """Create a new project.

     Create a new project by importing data either from a sitemap or an uploaded file. This endpoint
    enables you to initiate the creation of a new project by supplying the necessary project data that
    will be used as the context. You can choose to import the project structure and content from a
    sitemap url or upload a specific file format that contains the context can be any text, audio or
    video format. The system will process the provided data and generate a new project based on the
    imported or uploaded information.
    Here is an example to create a bot using a sitemap: [API](https://github.com/Poll-The-
    People/customgpt-cookbook/blob/main/examples/Create_Bot_By_Sitemap.ipynb)
    [SDK](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/SDK_Create_Bot_By_Sitemap.ipynb).

    Args:
        multipart_data (CreateProjectMultipartData):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[CreateProjectResponse201, CreateProjectResponse400, CreateProjectResponse401, CreateProjectResponse500]
    """

    return (
        await asyncio_detailed(
            client=client,
            multipart_data=multipart_data,
        )
    ).parsed



from enum import Enum


class CreateProjectResponse400DataMessage(str, Enum):
    PROJECT_NAME_CANT_BE_EMPTY = "Project name can't be empty"
    SITEMAP_PATH_CANT_BE_EMPTY = "Sitemap path can't be empty"
    YOU_HAVE_REACHED_YOUR_MONTHLY_PROJECT_LIMIT = "You have reached your monthly project limit"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class ProjectAnalyticsTrafficSourcesItemRequestSource(str, Enum):
    AI_ASSISTANT = "ai-assistant"
    API = "api"
    EMBED = "embed"
    INSTANT_VIEWER = "instant-viewer"
    LIVECHAT = "livechat"
    SGE = "sge"
    WEB = "web"

    def __str__(self) -> str:
        return str(self.value)
